﻿Imports System
Imports System.IO
Imports System.Security.Cryptography
Imports System.Security.Cryptography.X509Certificates
Imports System.Security.Cryptography.Xml
Imports System.Text
Imports System.Xml

Module Certs
    ' Haal het juiste certificaat op
    Function GetCertFromStore(ByVal gebruik As String) As X509Certificate2
        GetCertFromStore = Nothing

        ' Open de CurrentUser keystore
        ' (Ook zichtbaar te maken met certmgr command-line tool)
        Dim store As New X509Store("MY", StoreLocation.CurrentUser)
        ' ReadWrite is nodig als ClearAllCerts gebruikt wordt, anders is ReadOnly voldoende
        store.Open(OpenFlags.ReadWrite Or OpenFlags.OpenExistingOnly)

        Dim x509 As X509Certificate2

        ' Selecteer alle certificaten
        Dim collection As X509Certificate2Collection = store.Certificates
        ' Filter op alleen niet-verlopen certificaten
        Dim fcollection As X509Certificate2Collection = collection.Find(X509FindType.FindByTimeValid, DateTime.Now, False)
        ' Filter op juiste keyUsage voor EH resp. TA
        Dim scollection As New X509Certificate2Collection
        If gebruik = "TA" Then
            scollection = collection.Find(X509FindType.FindByKeyUsage, "DigitalSignature", False)
        ElseIf gebruik = "EH" Then
            scollection = fcollection.Find(X509FindType.FindByKeyUsage, "NonRepudiation", False)
        End If

        ' Voor eventueel debuggen, display
        'Console.WriteLine(scollection.Count)
        'For Each x509 In scollection
        '   Console.WriteLine(x509.FriendlyName & x509.GetSerialNumberString & x509.Subject)
        '   X509Certificate2UI.DisplayCertificate(x509)
        'Next

        ' Safesign <= 3.0.40 schoont de (eigen) keystore op na verwijderen pas, 
        ' er zal dus altijd nul (geen pas in lezer) of een certificaat zijn.
        ' 
        ' Safesign >= 3.0.45 gebruik de MS Keystore, deze behoudt certificaten
        ' na verwijderen pas, er kunnen er dus meer zijn, tenzij:
        ' - na(sessie) de keystore geschoond wordt, b.v. met ClearAllCerts
        ' - er maar een user werkt met deze login, en bij vervanging pas oude certificaat verwijderd wordt
        ' (kan met Safesign TokenAdmin of command line tool certmgr.exe)
        If scollection.Count = 0 Then
            ' Bij geen certificaten, foutmelding
            Dim aoCertificateException As New CryptographicException("Geen certificaat gevonden")
            Throw aoCertificateException
        ElseIf scollection.Count > 1 Then
            ' Bij meer certificaten, laat gebruiker er een kiezen 
            ' Een alternatief is kijken welke pas in de lezer zit, en het bijbehorende certificaat kiezen
            ' Dit kan niet in zuiver .Net, wel met de PKCS11 library van Safesign
            ' Het is niet nodig in contexten waar niet meer dan een enkel certificaat te verwachten is
            Console.WriteLine("Meer dan een certificaat: {0}{1}", scollection.Count, Environment.NewLine)
            x509 = X509Certificate2UI.SelectFromCollection(scollection, "Select an X509 Certificate", "Choose a certificate to examine.", X509SelectionFlag.SingleSelection)(0)
        Else
            ' Bij een certificaat, kies deze
            x509 = scollection(0)
        End If

        ' Geef gekozen cert terug
        GetCertFromStore = x509

        store.Close()
    End Function

    Function GetCertFromFile(ByVal Filename As String) As X509Certificate2
        ' Lees een certificaat uit een bestand
        ' DER (.der) of Base 64 (.cer) encoding
        GetCertFromFile = Nothing
        Try
            Dim x509 As X509Certificate2
            x509 = New X509Certificate2(Filename)
            GetCertFromFile = x509
            'PrintCertInfo(x509)
        Catch cExcept As CryptographicException
            Console.WriteLine("Information could not be written out for this certificate.")
        End Try
    End Function

    Function GetCertFromBase64(ByVal certdata() As Byte) As X509Certificate2
        ' Lees een certificaat uit een bestand
        ' DER (.der) of Base 64 (.cer) encoding
        GetCertFromBase64 = Nothing
        Try
            Dim x509 As X509Certificate2
            x509 = New X509Certificate2(certdata)
            GetCertFromBase64 = x509
            'PrintCertInfo(x509)
        Catch cExcept As CryptographicException
            Console.WriteLine("Information could not be written out for this certificate.")
        End Try
    End Function

    Function UziProps(ByVal x509 As X509Certificate2) As Dictionary(Of String, String)
        ' Haal de properties van de UZI pas op (CN en dergelijke)
        Dim l() As String
        Dim d As New Dictionary(Of String, String)
        l = x509.Subject.Split(",")
        For Each s In l
            d.Add(s.Substring(0, s.IndexOf("=")).Trim, s.Substring(s.IndexOf("=") + 1).Trim)
        Next
        Return d
    End Function

    Sub ClearAllCerts()
        ' Helper om alle certificaten in CurrentUser Personal store te verwijderen
        Dim store As New X509Store("MY", StoreLocation.CurrentUser)
        store.Open(OpenFlags.ReadWrite Or OpenFlags.OpenExistingOnly)
        Dim collection As X509Certificate2Collection = CType(store.Certificates, X509Certificate2Collection)
        Dim x509 As X509Certificate2
        For Each x509 In collection
            store.Remove(x509)
        Next
        store.Close()
    End Sub

    Sub SaveCert(ByVal x509 As X509Certificate2, ByVal FileName As String)
        ' Helper om een certificaat weg te schrijven als Base64 encoded .cer bestand
        Dim Cert As String

        Cert = "-----BEGIN CERTIFICATE-----" & vbCrLf & GetBase64Cert(x509) & "-----END CERTIFICATE-----"
        My.Computer.FileSystem.WriteAllText(FileName & ".cer", Cert, False)
    End Sub

    Function GetBase64Cert(ByVal x509 As X509Certificate2) As String
        ' Helper om base64 representatie van een certificaat te krijgen
        Dim s1 As String, s2 As String = ""

        s1 = Convert.ToBase64String(x509.Export(X509ContentType.Cert))
        Dim i As Integer = 0, LineLen As Integer = 64
        While i < Len(s1)
            s2 = s2 & s1.Substring(i, Min(LineLen, Len(s1) - i)) & vbCrLf
            i = i + LineLen
        End While

        Return s2
    End Function

    Function Min(ByVal i1 As Integer, ByVal i2 As Integer) As Integer
        ' Retourneer kleinste van twee ints
        If i1 < i2 Then
            Return i1
        Else
            Return i2
        End If
    End Function

    Sub PrintCertInfo(ByVal x509 As X509Certificate2)
        ' Helper voor printen certificaatinformatie bij debuggen
        Try
            Console.WriteLine("Friendly Name: {0}{1}", x509.FriendlyName, Environment.NewLine)
            Console.WriteLine("Certificate Verified?: {0}{1}", x509.Verify(), Environment.NewLine)
            Console.WriteLine("Simple Name: {0}{1}", x509.GetNameInfo(X509NameType.SimpleName, True), Environment.NewLine)
            Console.WriteLine("Signature Algorithm: {0}{1}", x509.SignatureAlgorithm.FriendlyName, Environment.NewLine)
            Console.WriteLine("Public Key: {0}{1}", x509.PublicKey.Key.ToXmlString(False), Environment.NewLine)
            Console.WriteLine("Certificate Archived?: {0}{1}", x509.Archived, Environment.NewLine)
            Console.WriteLine("Length of Raw Data: {0}{1}", x509.RawData.Length, Environment.NewLine)
            X509Certificate2UI.DisplayCertificate(x509)
        Catch cExcept As CryptographicException
            Console.WriteLine("Information could not be written out for this certificate.")
        End Try
    End Sub

End Module
