﻿Imports System
Imports System.IO
Imports System.Security.Cryptography
Imports System.Security.Cryptography.X509Certificates
Imports System.Security.Cryptography.Xml
Imports System.Text
Imports System.Xml

Module Sign
    ' Sign an XML file and save the signature in a new file. This method does not  
    ' save the public key within the XML file.  This file cannot be verified unless  
    ' the verifying code has the key with which it was signed.
    Sub SignXmlFile(ByVal Filename As String, ByVal SignedFileName As String, ByVal x509 As X509Certificate2, ByVal nsmgr As XmlNamespaceManager, ByVal gebruik As String, ByVal context As String, ByVal hashMethod As String)
        ' Key Usage Extension ophalen op OID
        Dim ext As X509KeyUsageExtension = CType(x509.Extensions("2.5.29.15"), X509KeyUsageExtension)
        If ext.KeyUsages = X509KeyUsageFlags.NonRepudiation And gebruik = "EH" Then
            ' OK
        ElseIf ext.KeyUsages = X509KeyUsageFlags.DigitalSignature And gebruik = "TA" Then
            ' OK
        Else
            Dim aoCertificateException As New CryptographicException("Geen geldig certificaat")
            Throw aoCertificateException
        End If

        ' Create a new XML document.
        Dim doc As New XmlDocument()
        doc.PreserveWhitespace = True
        Dim token As New XmlDocument()
        token.PreserveWhitespace = True

        ' Load the passed XML file using its name.
        doc.Load(Filename)
        token = GetToken(doc.DocumentElement, context)

        ' Create a SignedXml object.
        Dim signedXml As New SignedXml(token)

        ' MdG:
        ' x509.PrivateKey haalt de key op van de UZI-pas, ongeacht welk object aan x509 toegekend is
        ' is een bug in Safesign 3.0.45, wordt gefixt in volgende release (is toegezegd)
        signedXml.SigningKey = x509.PrivateKey

        ' Specify a canonicalization method.
        signedXml.SignedInfo.CanonicalizationMethod = signedXml.XmlDsigExcC14NTransformUrl

        ' Create a reference to be signed.
        Dim reference As New Reference()
        reference.Uri = "#" & GetWsuId(doc.DocumentElement, context, nsmgr)

        ' Add an enveloped transformation to the reference.
        reference.AddTransform(New XmlDsigExcC14NTransform())

        ' Add the reference to the SignedXml object.
        ' SHA256 digest werkt wel met signedXml
        If hashMethod = "SHA256" Then reference.DigestMethod = "http://www.w3.org/2001/04/xmlenc#sha256"
        signedXml.AddReference(reference)
        'Console.WriteLine("SHA2 digest: " & Base64ShaString(Filename, "SHA256", context))
        'Met rsa-sha256 volgt error bij sig berekenen
        'signedXml.SignedInfo.SignatureMethod = "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256"

        ' Compute the signature.
        signedXml.ComputeSignature()

        ' TODO
        ' Add the KeyInfo object to the SignedXml object
        ' Moet eigenlijk in wss:BinarySecurityToken voor EH
        If gebruik = "TA" Then
            Dim x509Data As New KeyInfoX509Data()
            x509Data.AddIssuerSerial(x509.IssuerName.Format(True), x509.SerialNumber)
            signedXml.KeyInfo.AddClause(x509Data)
        ElseIf gebruik = "EH" Then
            signedXml.KeyInfo.AddClause(New KeyInfoX509Data(x509))
        End If

        Dim sigNode As XmlNode = doc.ImportNode(signedXml.GetXml(), True)

        ' SignedXml ondersteunt geen rsa+sha256, dus de berekening van de sig buiten SignedXml om doen
        If hashMethod = "SHA256" Then
            Dim sig As String
            sig = GetSignature(signedXml, x509.PrivateKey, "SHA256")
            sigNode.SelectSingleNode("//ds:SignatureMethod/@Algorithm", nsmgr).Value = "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256"
            sigNode.SelectSingleNode("//ds:SignatureValue", nsmgr).InnerText = sig
        End If

        ' WS-Security vereist een wss:SecurityTokenReference element in ds:KeyInfo, toevoegen
        Dim wssReferenceNode As XmlElement = doc.CreateElement("wss", "SecurityTokenReference", nsmgr.LookupNamespace("wss"))
        wssReferenceNode.AppendChild(sigNode.SelectSingleNode("//ds:X509Data", nsmgr))
        sigNode.SelectSingleNode("//ds:KeyInfo", nsmgr).AppendChild(wssReferenceNode)

        ' Get the XML representation of the signature and save
        ' it to an XmlElement object.
        Dim wssNode As XmlElement = doc.CreateElement("wss", "Security", nsmgr.LookupNamespace("wss"))
        wssNode.AppendChild(sigNode)
        wssNode.SetAttribute("mustUnderstand", nsmgr.LookupNamespace("soap"), "1")
        If gebruik = "EH" Then
            wssNode.SetAttribute("actor", nsmgr.LookupNamespace("soap"), "http://www.aortarelease.nl/actor/gbx")
        Else
            wssNode.SetAttribute("actor", nsmgr.LookupNamespace("soap"), "http://www.aortarelease.nl/actor/zim")
        End If

        If gebruik = "EH" Then
            ' Bij de elektronische handtekening moet meegezonden certificaat in een wss:BinarySecurityToken
            ' De ds:KeyInfo moet aan die node refereren
            ' Maak een string voor URI en verwijzing
            Dim certref As String = "signing-cert"
            ' Maak een wss:BinarySecurityToken node
            Dim wssBinSecNode As XmlElement = doc.CreateElement("wss", "BinarySecurityToken", nsmgr.LookupNamespace("wss"))
            wssBinSecNode.SetAttribute("ValueType", "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-x509-token-profile-1.0#X509v3")
            wssBinSecNode.SetAttribute("EncodingType", "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-soap-message-security-1.0#Base64Binary")
            wssBinSecNode.SetAttribute("Id", nsmgr.LookupNamespace("wsu"), certref)
            ' Voeg het certificaat in vanuit door ingevoegde ds:X509Certificate node
            wssBinSecNode.InnerText = sigNode.SelectSingleNode("//ds:X509Certificate", nsmgr).InnerText
            wssNode.AppendChild(wssBinSecNode)
            ' Haal certificaat weg uit wss:SecurityTokenReference node, zet verwijzing
            wssReferenceNode.InnerXml = ""
            wssReferenceNode.SetAttribute("ValueType", "http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-x509-token-profile-1.0#X509v3")
            wssReferenceNode.SetAttribute("URI", "#" & certref)
        End If
        ' Voeg de wss:Security header toe
        doc.DocumentElement.SelectNodes("//soap:Header", nsmgr)(0).AppendChild(wssNode)

        ' Opschonen en save
        RemoveDtdDeclaration(doc)
        doc.Save(SignedFileName)
    End Sub

    Function GetSignature(ByVal signedXml As SignedXml, ByVal Key As RSACryptoServiceProvider, ByVal ShaVersion As String) As String
        ' Zet een RSA+SHA256 handtekening op een SignedXml
        ' SignedXml class zelf ondersteunt geen RSA+SHA256
        ' Input:
        ' - te ondertekenen SignedXml
        ' - private key
        ' - shaVersion, is getest en werkt met "SHA256", werkt mogelijk met andere hashes als juiste URI ipv. rsa-sha256 gebruikt wordt
        ' Output:
        ' - string met Base64 encoded RSA signature value over [shaVersion] gehashte signedInfo deel van signedXml
        Dim excc14n As New XmlDsigExcC14NTransform
        Dim si As New XmlDocument()
        Dim xmlString As String
        Dim sigBytes() As Byte

        ' Altijd PreserveWhitespace aan, anders gaat .Net pretty-printen en valideert sig niet meer
        si.PreserveWhitespace = True
        ' Neem SignedInfo deel van SignedXml als string voor vervangen URI
        xmlString = signedXml.SignedInfo.GetXml.OuterXml()
        ' Vervang SignatureMethod/@Algorithm
        xmlString = xmlString.Replace("http://www.w3.org/2000/09/xmldsig#rsa-sha1", "http://www.w3.org/2001/04/xmldsig-more#rsa-sha256")
        ' Laden als XML
        si.LoadXml(xmlString)
        ' Exclusive XML Canonicalization
        excc14n.LoadInput(si)
        ' Zet de handtekening binair
        sigBytes = Key.SignData(excc14n.GetOutput(), ShaVersion)
        ' Converteer sig naar Base64 en retourneer
        Return Convert.ToBase64String(sigBytes)
    End Function

End Module
