package nl.nictiz.digsig;

import static org.apache.ws.security.WSSecurityEngineResult.TAG_ACTION;
import static org.apache.ws.security.WSSecurityEngineResult.TAG_PRINCIPAL;
import static org.apache.ws.security.WSSecurityEngineResult.TAG_X509_CERTIFICATE;

import java.io.FileNotFoundException;
//import java.io.FileOutputStream;
import java.io.IOException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.Properties;
import java.util.Vector;

import javax.xml.parsers.ParserConfigurationException;


import org.apache.ws.security.WSConstants;
import org.apache.ws.security.WSSecurityEngine;
import org.apache.ws.security.WSSecurityEngineResult;
import org.apache.ws.security.WSSecurityException;
import org.apache.ws.security.components.crypto.Crypto;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

/**
 * A validator for WS-Security signatures. Validates only the signature, if
 * possible. Does not verify the contents of the message or the token!
 */
public class WssValidate
	extends WssCommon
{

	/**
	 * Constants with the different SOAP-actors that may be used.
	 */
	private static final String ACTOR_GBX =
		"http://www.aortarelease.nl/actor/gbx"; 
	private static final String ACTOR_ZIM =
		"http://www.aortarelease.nl/actor/zim"; 

	/**
	 * @param args
	 * @throws IOException 
	 * @throws SAXException 
	 * @throws ParserConfigurationException 
	 * @throws FileNotFoundException 
	 * @throws CertificateException 
	 * @throws NoSuchAlgorithmException 
	 * @throws KeyStoreException 
	 */
	public static void main(String[] args) throws FileNotFoundException,
		ParserConfigurationException, SAXException, IOException,
		KeyStoreException, NoSuchAlgorithmException, CertificateException
	{

		Document envelope = XmlCommon.getDocument(args[0]);

		// Get the configuration to use
		Properties pkcs11properties = SmartCard.loadPkcsConfiguration();
		
		// Access the smartcard. This will load the PKCS#11 provider, which
		// is used as the keystore with certificates against which to check the
		// signature
		char[] pincode = SmartCard.readPassword();
		SmartCard smartCard =
			new SmartCard(pincode, pkcs11properties);

		WSSecurityEngine secEngine = WSSecurityEngine.getInstance();

		Crypto crypto = makeWssCrypto();

		System.out.println("Validating signatures targeted at next hop");
		validateSignatures(envelope, secEngine, crypto, null);

		System.out.println("Validating signatures targeted at LSP");
		validateSignatures(envelope, secEngine, crypto, ACTOR_ZIM);

		System.out.println("Validating signatures targeted at GBZ");
		validateSignatures(envelope, secEngine, crypto, ACTOR_GBX);

	}

	private static void validateSignatures(Document envelope,
			WSSecurityEngine securityEngine, Crypto crypto, String soapActor)
			throws WSSecurityException {

		System.out.println(" - SOAP-actor: " + soapActor);

		Vector results =
			securityEngine.processSecurityHeader(envelope, soapActor, null, crypto);
		if (results == null) {
			System.out.println(" => No such signatures");
			return;
		}
		for (Object o : results) {
			WSSecurityEngineResult result = (WSSecurityEngineResult)o;
			// Note: an encryption action does not have an associated principal
			// only Signature and UsernameToken actions return a principal
		    if ( (Integer)result.get(TAG_ACTION) == WSConstants.SIGN) {
		        System.out.println(" => " + result.get(TAG_PRINCIPAL));
		        displayCertificateInformation(result);
		    }
		}
	}

	private static void displayCertificateInformation(
			WSSecurityEngineResult result) {

		Object x509certificate = result.get(TAG_X509_CERTIFICATE);
		if (x509certificate instanceof X509Certificate) {
			X509Certificate signatureCertificate =
				(X509Certificate) x509certificate;
//          // Save certificate in binary format
//			FileOutputStream fos = new FileOutputStream("/tmp/sigcert");
//			fos.write(signatureCertificate.getEncoded());
//			fos.close();
			if (signatureCertificate.getKeyUsage()[0]) {
				System.out.println("    Signed with certificate for " +
						"authentication (digital signature, TA)");
			}
			else if (signatureCertificate.getKeyUsage()[1]) {
				System.out.println("    Signed with certificate for " +
						"electronic signature (non-repudiation, EH)");
			}
		}
	}

}