<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:hl7="urn:hl7-org:v3" exclude-result-prefixes="#all"
    xmlns:File="java:java.io.File" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:ztr="urn:Nictiz.AORTA.CareApplicationData">

    <xd:doc xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Jan 18, 2010</xd:p>
            <xd:p><xd:b>Author:</xd:b> ahenket</xd:p>
            <xd:p/>
        </xd:desc>
    </xd:doc>
    
    <xsl:variable name="systeemrolFile" select="'../../vocab/2.16.840.1.113883.2.4.3.11.3.xml'"/>
    <xsl:variable name="interactionFile" select="'../../vocab/2.16.840.1.113883.1.6.xml'"/>

    <xsl:output method="html" indent="yes" version="4.01" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.01//EN"
        doctype-system="http://www.w3.org/TR/html4/strict.dtd"/>
    <xsl:template match="/">
        <html>
            <head>
                <title>Systeemrollen</title>
                <script type="text/javascript">
                    function toggle(toggled,toggler) {
                    if (document.getElementById) {
                    var currentStyle = document.getElementById(toggled).style;
                    var togglerStyle = document.getElementById(toggler).style;
                    if (currentStyle.display == "block"){
                    currentStyle.display = "none";
                    togglerStyle.backgroundImage = "url(../../css/trClosed.gif)";
                    } else {
                    currentStyle.display = "block";
                    togglerStyle.backgroundImage = "url(../../css/triangleOpen.gif)";
                    }
                    return false;
                    } else {
                    return true;
                    }
                    }
                </script>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <link href="../../css/nictiz.css" type="text/css" rel="stylesheet"/>
            </head>
            <body>
                <h1>Overzicht systeemrollen</h1>
                <p/>
                <xsl:apply-templates select="/ztr:CareApplicationData/ztr:CareApplicationRole"/>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="ztr:CareApplicationRole">
        <xsl:variable name="systeemrolId" select="./ztr:CARName"/>
        <xsl:call-template name="headingToggle">
            <xsl:with-param name="label">
                <xsl:value-of select="$systeemrolId"/>
                <xsl:text> (release: </xsl:text>
                <xsl:value-of select="./ztr:CARRelease"/>
                <xsl:text>) - </xsl:text>
                <xsl:value-of select="document($systeemrolFile)/*/hl7:code[@code=$systeemrolId]/@displayName"/>
            </xsl:with-param>
            <xsl:with-param name="heading" select="'h2'"/>
        </xsl:call-template>
    </xsl:template>
    <xsl:template match="ztr:SupportedInteraction">
        <xsl:variable name="interactionId" select="ztr:InteractionID"/>
        <tr>
            <xsl:if test="document($interactionFile)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='Actief']/@value='false'">
                <xsl:attribute name="style">
                    <xsl:value-of select="'text-decoration: line-through;'"/>
                </xsl:attribute>
            </xsl:if>
            <td class="value">
                <xsl:value-of select="ztr:InteractionID"/>
            </td>
            <td class="value">
                <xsl:apply-templates select="ztr:Sending" mode="trueFalse"/>
            </td>
            <td class="value">
                <xsl:apply-templates select="ztr:Receiving" mode="trueFalse"/>
            </td>
            <td>
                <xsl:value-of select="document($interactionFile)/*/hl7:code[@code=$interactionId]/@displayName"/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="ztr:Sending | ztr:Receiving" mode="trueFalse">
        <xsl:choose>
            <xsl:when test="string(@required)='true' and string(.)='true'">
                <xsl:text>Verplicht</xsl:text>
            </xsl:when>
            <xsl:when test="string(@required)='true' and string(.)='false'">
                <!--xsl:text>Verboden</xsl:text-->
                <span title="Verboden">--</span>
            </xsl:when>
            <xsl:when test="string(@required)='false' and string(.)='true'">
                <xsl:text>Optioneel</xsl:text>
            </xsl:when>
            <xsl:when test="string(@required)='false' and string(.)='false'">
                <span style="font-weight: bold;color:red;">(n.v.t.)</span>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Fout in configuratie!</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Template voor heading waarop een div volgt die opengeklikt kan worden -->
    <xsl:template name="headingToggle">
        <xsl:param name="label"/>
        <xsl:param name="heading"/>
        <xsl:variable name="id" select="generate-id()"/>
        <xsl:variable name="id-toggler" select="concat($id,'-toggler')"/>
        <xsl:element name="{$heading}">
            <xsl:attribute name="class" select="'toggler'"/>
            <xsl:attribute name="id" select="$id-toggler"/>
            <xsl:attribute name="onclick" select="concat('return toggle(&quot;',$id,'&quot;,&quot;',$id-toggler,'&quot;)')"/>
            <xsl:value-of select="$label"/>
        </xsl:element>
        <div class="level2">
            <xsl:element name="div">
                <xsl:attribute name="id" select="$id"/>
                <xsl:attribute name="class" select="'toggle'"/>
                <table class="values">
                    <tr>
                        <th class="value-label">Interactie</th>
                        <th class="value-label">Versturen</th>
                        <th class="value-label">Ontvangen</th>
                        <th class="value-label">Naam</th>
                    </tr>
                    <xsl:apply-templates select="ztr:SupportedInteraction"/>
                </table>
            </xsl:element>
        </div>
    </xsl:template>
</xsl:stylesheet>
