<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="template-2.16.840.1.113883.2.4.6.10.100.163" see="http://wiki.hl7.org/index.php?title=Implementatiehandleiding_HL7v3_basiscomponenten_v2.2_Part3#CMET_E_PersonNLInformatiemodel">
    <title>E_PersonNL_JGZ Informal identified/confirmable</title>
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='PSN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityClass.htm#PSN"
            >template-2.16.840.1.113883.2.4.6.10.100.163: @classCode moet indien aanwezig 'PSN' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='INSTANCE'"  see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/EntityDeterminer.htm#INSTANCE"
            >template-2.16.840.1.113883.2.4.6.10.100.163: @determinerCode moet indien aanwezig 'INSTANCE' zijn</assert>
        <assert role="error" test="count(hl7:name) &lt;=2"
            >template-2.16.840.1.113883.2.4.6.10.100.163: er mogen niet meer dan 2 persoonsnamen zijn</assert>
        <assert role="error" test="hl7:administrativeGenderCode"
            >template-2.16.840.1.113883.2.4.6.10.100.163: administrativeGenderCode is verplicht</assert>
        <assert role="error" test="hl7:birthTime"
            >template-2.16.840.1.113883.2.4.6.10.100.163: birthTime is verplicht</assert>
    </rule>
    <rule context="$element/hl7:name">
        <extends rule="PN"/>
        <assert role="error" test="not(@use) or @use='OR' or @use='L'"
            >template-2.16.840.1.113883.2.4.6.10.100.163: @use moet indien aanwezig 'OR' of 'L' zijn</assert>
        <assert role="error" test="hl7:given and not(hl7:given/@qualifier)"
            >template-2.16.840.1.113883.2.4.6.10.100.163: given is verplicht en mag geen @qualifier hebben</assert>
        <assert role="error" test="not(hl7:prefix) or hl7:prefix/@qualifier='VV BR' or hl7:prefix/@qualifier='BR VV'"
            >template-2.16.840.1.113883.2.4.6.10.100.163: prefix moet, indien aanwezig, voorvoegsels van de geslachtsnaam bevatten</assert>
        <assert role="error" test="hl7:family and hl7:family/@qualifier='BR'"
            >template-2.16.840.1.113883.2.4.6.10.100.163: family moet de geslachtsnaam bevatten</assert>
    </rule>
    <rule context="$element/hl7:administrativeGenderCode">
        <extends rule="CE"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1'"
            >template-2.16.840.1.113883.2.4.6.10.100.163: geslacht moet komen uit codesysteem '2.16.840.1.113883.5.1'</assert>
    </rule>
    <rule context="$element/hl7:birthTime">
        <extends rule="TS"/>
    </rule>
    <rule context="$element/hl7:multipleBirthInd">
        <extends rule="BL"/>
    </rule>
    <rule context="$element/hl7:multipleBirthOrderNumber">
        <extends rule="INT"/>
        <assert role="error" test="preceding-sibling::hl7:multipleBirthInd/@value='true'"
            >template-2.16.840.1.113883.2.4.6.10.100.163: dit element kan alleen een waarde hebben als multipleBirthInd/@value='true'</assert>
        <assert role="error" test="number(@value) &gt;= 1"
            >template-2.16.840.1.113883.2.4.6.10.100.163: @value moet >= 1 zijn</assert>
    </rule>
    
    <title>contactParty</title>
    <rule context="$element/hl7:contactParty">
        <assert test="hl7:telecom"
            >template-2.16.840.1.113883.2.4.6.10.100.163: telecom is verplicht</assert>
        <assert test="hl7:contactPerson/hl7:name"
            >template-2.16.840.1.113883.2.4.6.10.100.163: contactPerson/name is verplicht</assert>
    </rule>
    <rule context="$element/hl7:contactParty/hl7:code">
        <extends rule="CE"/>
        <assert role="error" test="@nullFlavor or @codeSystem='2.16.840.1.113883.5.111'"
            >template-2.16.840.1.113883.2.4.6.10.100.163: contactpersoon code moet komen uit codesysteem '2.16.840.1.113883.5.111'</assert>
    </rule>
    <rule context="$element/hl7:contactParty/hl7:telecom">
        <extends rule="TEL"/>
    </rule>
    <rule context="$element/hl7:contactParty/hl7:effectiveTime">
        <extends rule="IVL_TS"/>
        <assert role="error" test="hl7:low or hl7:high"
            >template-2.16.840.1.113883.2.4.6.10.100.163: low en/of high is verplicht</assert>
        <assert role="error" test="not(hl7:width or hl7:center)"
            >template-2.16.840.1.113883.2.4.6.10.100.163: width en/of center zijn niet toegestaan</assert>
    </rule>
    <rule context="$element/hl7:contactParty/hl7:contactPerson">
        <assert role="error" test="not(@classCode) or @classCode='PSN'"
            >template-2.16.840.1.113883.2.4.6.10.100.163: @classCode moet indien aanwezig 'PSN' zijn</assert>
        <assert role="error" test="not(@determinerCode) or @determinerCode='INSTANCE'"
            >template-2.16.840.1.113883.2.4.6.10.100.163: @determinerCode moet indien aanwezig 'INSTANCE' zijn</assert>
    </rule>
    <rule context="$element/hl7:contactParty/hl7:contactPerson/hl7:name">
        <extends rule="PN"/>
    </rule>
</pattern>