<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="template-2.16.840.1.113883.2.4.6.10.100.180">
    <title>Versturen toegediende vaccinaties</title>
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='PCPR'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @classCode moet indien aanwezig de waarde 'PCPR' hebben</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @moodCode moet indien aanwezig de waarde 'EVN' hebben</assert>
        <assert test="count(hl7:subject)=1"
            >template-2.16.840.1.113883.2.4.6.10.100.180: er moet exact één element subject (Patiëntgegevens) zijn</assert>
        <assert test="count(hl7:performer)=1"
            >template-2.16.840.1.113883.2.4.6.10.100.180: er moet exact één element performer (Uitvoerende gegevens) zijn</assert>
        <assert test="count(hl7:author)=1"
            >template-2.16.840.1.113883.2.4.6.10.100.180: er moet exact één element author (Verantwoordelijke gegevens) zijn</assert>
    </rule>
    <rule context="$element/hl7:id">
        <extends rule="II"/>
        <assert role="error" test="not(@nullFlavor)"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @nullFlavor is niet toegestaan</assert>
    </rule>
    <rule context="$element/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="@code='CPHC' and @codeSystem='2.16.840.1.113883.5.4'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @code moet 'CPHC' zijn en @codeSystem '2.16.840.1.113883.5.4'</assert>
    </rule>
    <rule context="$element/hl7:statusCode">
        <extends rule="CS"/>
        <assert role="error" test="@code='active' or @code='completed' or @code='aborted'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @code moet 'active', 'completed', of 'aborted' zijn</assert>
    </rule>

    <title>CareProvisionEvent/author</title>
    <rule context="$element/hl7:author">
        <assert role="error" test="not(@typeCode) or @typeCode='AUT'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @typeCode moet indien aanwezig de waarde 'AUT' hebben</assert>
        
        <let name="authorOrganizationId" value="(hl7:assignedEntity//hl7:id[@root='2.16.528.1.1007.3.3'])[1]/@extension"/>
        <let name="performerOrganizationId" value="(../hl7:performer/hl7:assignedEntity//hl7:id[@root='2.16.528.1.1007.3.3'])[1]/@extension"/>
        <let name="sbadmPerformerOrganizationId" value="(..//hl7:substanceAdministrationEvent/hl7:performer/hl7:assignedEntity//hl7:id[@root='2.16.528.1.1007.3.3'])[1]/@extension"/>
        
        <assert role="warning" test="empty($authorOrganizationId) or empty($performerOrganizationId) or $authorOrganizationId=$performerOrganizationId"
            >template-2.16.840.1.113883.2.4.6.10.100.180: het organisatie-id van de auteur (<value-of select="$authorOrganizationId"/>) en de uitvoerende (<value-of select="$performerOrganizationId"/>) van het dossier komen niet overeen. Dat kan alleen in geval van gastgebruik</assert>
        <assert role="warning" test="empty($authorOrganizationId) or empty($sbadmPerformerOrganizationId) or $authorOrganizationId=$sbadmPerformerOrganizationId"
            >template-2.16.840.1.113883.2.4.6.10.100.180: het organisatie-id van de auteur (<value-of select="$authorOrganizationId"/>) van het dossier en die van de uitvoerende (<value-of select="$sbadmPerformerOrganizationId"/>) van de vaccinatie komen niet overeen. Dat kan alleen in geval van gastgebruik</assert>
        
        <assert role="error" test="hl7:*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.100.122']"
            >template-2.16.840.1.113883.2.4.6.10.100.117: <name/> moet gekoppeld zijn met R_AssignedEntityNL_PO template-2.16.840.1.113883.2.4.6.10.100.122</assert>
    </rule>

    <title>CareProvisionEvent/performer</title>
    <rule context="$element/hl7:performer">
        <assert role="error" test="not(@typeCode) or @typeCode='PRF'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @typeCode moet indien aanwezig de waarde 'PRF' hebben</assert>
        
        <assert role="error" test="hl7:*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.100.122']"
            >template-2.16.840.1.113883.2.4.6.10.100.180: <name/> moet gekoppeld zijn met R_AssignedEntityNL_PO template-2.16.840.1.113883.2.4.6.10.100.122</assert>
    </rule>
    
    <title>CareProvisionEvent/subject</title>
    <rule context="$element/hl7:subject">
        <assert role="error" test="not(@typeCode) or @typeCode='SBJ'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @typeCode moet indien aanwezig de waarde 'SBJ' hebben</assert>
        
        <assert role="error" test="hl7:*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.100.102']"
            >template-2.16.840.1.113883.2.4.6.10.100.180: <name/> moet gekoppeld zijn met R_PatientNL_JGZ identified/confirmable template-2.16.840.1.113883.2.4.6.10.100.102</assert>
    </rule>

    <title>CareProvisionEvent/component</title>
    <rule context="$element/hl7:component">
        <assert role="error" test="not(@typeCode) or @typeCode='COMP'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @typeCode moet indien aanwezig de waarde 'COMP' hebben</assert>
    </rule>

    <title>CareProvisionEvent/component/encounterEvent</title>
    <rule context="$element/hl7:component/hl7:encounterEvent">
        <assert role="error" test="not(@classCode) or @classCode='ENC'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @classCode moet indien aanwezig de waarde 'ENC' hebben</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @moodCode moet indien aanwezig de waarde 'EVN' hebben</assert>
    </rule>
    <rule context="$element/hl7:component/hl7:encounterEvent/hl7:id">
        <extends rule="II"/>
    </rule>
    <rule context="$element/hl7:component/hl7:encounterEvent/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="not(@nullFlavor)"
            >template-2.16.840.1.113883.2.4.6.10.100.180: <name/> is mandatory</assert>
        <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.40.308'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: <name/> moet komen uit @codeSystem '2.16.840.1.113883.2.4.4.40.308' </assert>
    </rule>
    <rule context="$element/hl7:component/hl7:encounterEvent/hl7:effectiveTime">
        <extends rule="TS"/>
        <assert role="error" test="not(@nullFlavor)"
            >template-2.16.840.1.113883.2.4.6.10.100.180: <name/> is mandatory en moet een waarde hebben</assert>
    </rule>

    <title>CareProvisionEvent/component/encounterEvent/component</title>
    <rule context="$element/hl7:component/hl7:encounterEvent/hl7:component">
        <assert role="error" test="not(@typeCode) or @typeCode='COMP'"
            >template-2.16.840.1.113883.2.4.6.10.100.180: @typeCode moet indien aanwezig de waarde 'COMP' hebben</assert>
        <assert role="error" test="hl7:*[hl7:templateId/@root='2.16.840.1.113883.2.4.6.10.100.117']"
            >template-2.16.840.1.113883.2.4.6.10.100.180: component moet gekoppeld zijn met A_Rijksvaccinatie template-2.16.840.1.113883.2.4.6.10.100.117</assert>
    </rule>
 </pattern>
