<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van REPC_IN990003NL - Primary Care Locum Report</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/xml.sch"/>
    <include href="coreschematron/attentionLine.sch"/>

    <include href="coreschematron/transmission-wrapper.sch"/>
    <include href="coreschematron/controlAct-wrapper.sch"/>
    
    <include href="coreschematron/COCT_MT050000NL.sch"/>
    <include href="coreschematron/COCT_MT090000NL2.sch"/>
    <include href="coreschematron/COCT_MT090100NL.sch"/>
    <include href="WDH/COCT_MT120000NL_JE.sch"/>
    <include href="WDH/COCT_MT120100NL.sch"/>
    <include href="WDH/COCT_MT120100NL_CI.sch"/>
    <include href="WDH/COCT_MT120104NL.sch"/>
    <include href="WDH/COCT_MT990001NL.sch"/>
    <include href="WDH/COCT_MT990004NL.sch"/>
    <include href="WDH/REPC_MT000100UV01-Observation.sch"/>
    <include href="Mp/COCT_MT924000NL.sch"/>
    <include href="Mp/COCT_MT932000NL.sch"/>
    
    <!-- List of valid UCUM codes including '1' (default unit) -->
    <let name="ucumList" value="tokenize('% Cel cm d dB a kg kg/m2 L L/min m mg/L mg/mL mg/mmol umol/L mL/min mL/min/1.73m2 mm[Hg] mmol/L mmol/mol wk /min 1','\s+')"/>

    <!--pattern is-a="attentionLine" id="REPC_IN990003NL-attentionLine">
        <param name="messagePatientId"
            value="hl7:ControlActProcess/hl7:subject/hl7:PrimaryCareProvision/hl7:subject/hl7:Patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"/>
        <param name="attentionLineOptional" value="'true'"/>
    </pattern-->
    
    <pattern is-a="transmission-wrapper" id="REPC_IN990003NL-wrapper">
        <param name="element" value="hl7:REPC_IN990003NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="REPC_IN990003NL-controlAct">
        <param name="element" value="hl7:REPC_IN990003NL/hl7:ControlActProcess"/>
    </pattern>
    
    <!-- Extra wrapper controles -->
    <pattern>
        <!-- profileId -->
        <rule context="hl7:REPC_IN990003NL/hl7:profileId">
            <extends rule="II"/>
            <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
                >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
        </rule>
        <rule context="hl7:REPC_IN990003NL/hl7:acceptAckCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='AL'"
                >In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'AL'.</assert>
        </rule>
        <rule context="hl7:REPC_IN990003NL/hl7:attentionLine">
            <assert role="warning" test="not(.)"
                >Het gebruik van attentionLine wordt nog niet gespecificeerd in deze interactie.</assert>
        </rule>
        <rule context="hl7:REPC_IN990003NL/hl7:ControlActProcess/hl7:authorOrPerformer">
            <assert role="error"
                test="hl7:participant/hl7:AssignedPerson/hl7:id/@root='2.16.528.1.1007.3.1'"
                >OID root van AssignedPerson/id wijst niet naar UZI register personen</assert>
            <assert role="error"
                test="hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@root='2.16.528.1.1007.3.3'"
                >OID root van Organization/id wijst niet naar UZI register instellingen</assert>
        </rule>
    </pattern>
    
    <!-- text attributen -->
    <pattern>
        <title>text attributen moeten vrije tekst bevatten</title>
        <rule context="hl7:PrimaryCareProvision//hl7:text">
            <extends rule="ED"/>
            <assert role="error" test="not(@mediaType) or @mediaType='text/plain'"
                ><name path=".."/>/<name/> mag alleen als vrije tekst (mediaType='text/plain') worden gebruikt. Andere waarden zijn niet toegestaan</assert>
            <assert role="error" test="not(@representation) or @representation='TXT'"
                ><name path=".."/>/<name/> mag alleen als vrije tekst (representation='TXT') worden gebruikt. Andere waarden zijn niet toegestaan</assert>
            <assert role="error" test="not(@integrityCheck or @integrityCheckAlgorithm or @updateMode)"
                ><name path=".."/>/<name/> mag alleen attributen xsi:type, mediaType, representation, of language hebben</assert>
            <assert role="error" test="not(child::*)"
                ><name path=".."/>/<name/> mag geen elementen bevatten</assert>
            <assert role="error" test="string-length(.)>0"
                ><name path=".."/>/<name/>/text() is verplicht</assert>
        </rule>
    </pattern>
    
    <!-- PrimaryCareProvision -->
    <pattern>
        <title>PrimaryCareProvision Act</title>
        <rule context="hl7:PrimaryCareProvision">
            <assert role="error" test="not(@classCode) or @classCode='PCPR'"
                ><name/>/@classCode moet, indien anwezig, 'PCPR' bevatten</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='EVN'"
                ><name/>/@moodCode moet, indien anwezig, 'EVN' bevatten</assert>
            
            <assert test="hl7:id"
                ><name path=".."/>/<name/> is verplicht</assert>
            <assert test="hl7:statusCode"
                ><name path=".."/>/<name/> is verplicht</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root and @extension"
                ><name path=".."/>/<name/>/@root en @extension zijn verplicht</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='completed'"
                ><name path=".."/>/<name/>/@code moet 'active' bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value or @nullFlavor='UNK'"
                ><name path=".."/>/<name/>/low/@value moet de startdatum bevatten, of <name/>/@nullFlavor moet "UNK" zijn</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:text">
            <extends rule="ST"/>
            <report role="warning" test="hl7:text"
                ><name path=".."/>/<name/> element heeft een waarde. Het komt zelden voor dat hier iets in zou kunnen staan dat niet eigenlijk
                thuishoort in een ander deel, zoals een attentieregel, of een journaalregel.</report>
        </rule>
        
        <!-- participations -->
        <!-- Patiëntgegevens -->
        <rule context="hl7:PrimaryCareProvision/hl7:subject">
            <assert role="error" test="not(@typeCode) or  @typeCode='SBJ'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'SBJ' bevatten</assert>
            <assert role="error" test="not(@contextControlCode) or @contextControlCode='AP'"
                ><name path=".."/>/<name/>/@contextControlCode moet, indien anwezig, 'AP' bevatten</assert>
        </rule>
        
        <!-- ActRelationships -->
        <!-- Annotations -->
        <rule context="hl7:PrimaryCareProvision/hl7:pertinentInformation">
            <assert role="error" test="not(@typeCode) or  @typeCode='PERT'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'PERT' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='true'"
                ><name path=".."/>/<name/>/@contextConductionInd moet, indien aanwezig, 'true' bevatten</assert>
        </rule>
        
        <!-- Encounter -->
        <rule context="hl7:PrimaryCareProvision/hl7:component1">
            <assert role="error" test="not(@typeCode) or  @typeCode='COMP'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'COMP' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='true'"
                ><name path=".."/>/<name/>/@contextConductionInd moet, indien aanwezig, 'true' bevatten</assert>
        </rule>
        
        <!-- Activities -->
        <rule context="hl7:PrimaryCareProvision/hl7:component2">
            <assert role="error" test="not(@typeCode) or  @typeCode='COMP'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'COMP' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='true'"
                ><name path=".."/>/<name/>/@contextConductionInd moet, indien aanwezig, 'true' bevatten</assert>
        </rule>
        
        <!-- EpisodeOfCondition -->
        <rule context="hl7:PrimaryCareProvision/hl7:component3">
            <assert role="error" test="not(@typeCode) or  @typeCode='COMP'"
                ><name/>/@typeCode moet, indien anwezig, 'COMP' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='true'"
                ><name/>/@contextConductionInd moet, indien aanwezig, 'true' bevatten</assert>
        </rule>
    </pattern>
    
    <!-- R_Patient -->
    <pattern is-a="COCT_MT050000NL" id="REPC_IN990003NL-COCT_MT050000NL">
        <param name="element" value="hl7:PrimaryCareProvision//hl7:Patient"/>
    </pattern>
    
    <!-- AssignedEntity -->
    <pattern is-a="COCT_MT090000NL2" id="REPC_IN990003NL-COCT_MT090000NL2">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:*[local-name()='author' or local-name()='performer' or local-name()='custodian']/hl7:*"/>
    </pattern>
    <!-- AssignedPerson -->
    <pattern is-a="COCT_MT090100NL" id="REPC_IN990003NL-COCT_MT090100NL-pertinentInformation">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:pertinentInformation/hl7:*/hl7:*[local-name()='author' or local-name()='dataEnterer' or local-name()='performer' or local-name()='custodian']/hl7:*"/>
    </pattern>
    <pattern is-a="COCT_MT090100NL" id="REPC_IN990003NL-COCT_MT090100NL-component1">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:*[local-name()='author' or local-name()='dataEnterer' or local-name()='performer' or local-name()='custodian']/hl7:*"/>
    </pattern>
    <pattern is-a="COCT_MT090100NL" id="REPC_IN990003NL-COCT_MT090100NL-component1-activities">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:*/hl7:*[local-name()='author' or local-name()='dataEnterer' or local-name()='performer' or local-name()='custodian']/hl7:*"/>
    </pattern>
    <pattern is-a="COCT_MT090100NL" id="REPC_IN990003NL-COCT_MT090100NL-component2">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component2/hl7:*[local-name()='author' or local-name()='dataEnterer' or local-name()='performer' or local-name()='custodian']/hl7:*"/>
    </pattern>
    <pattern is-a="COCT_MT090100NL" id="REPC_IN990003NL-COCT_MT090100NL-component3">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:*[local-name()='author']/hl7:*"/>
    </pattern>
    
    <!-- episodeOfCondition -->
    <pattern>
        <title>Episodes, EpisodeOfCondition deel</title>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition">
            <assert role="error" test="not(@classCode) or @classCode='COND'"
                ><name/>/@classCode moet, indien anwezig, 'COND' bevatten</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='EVN'"
                ><name/>/@moodCode moet, indien anwezig, 'EVN' bevatten</assert>
            
            <assert test="hl7:statusCode"
                ><name path=".."/>/<name/> is verplicht</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root and @extension"
                ><name path=".."/>/<name/>/@root en @extension zijn verplicht</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:text">
            <extends rule="ST"/>
            <assert role="error" test="string-length(.)>0"
                ><name path=".."/>/<name/>/text() is verplicht</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='active' or @code='completed'"
                ><name path=".."/>/<name/>/@code moet 'active' of 'completed' bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                ><name path=".."/>/<name/>/low/@value moet de startdatum bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition">
            <assert role="error" test="not(hl7:component1/hl7:episodeOfCondition/hl7:component1)"
                >Episodes mogen slechts 1 niveau diep genest worden</assert>
        </rule>
        
        <!-- participations -->
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:author">
            <assert role="error" test="not(@typeCode) or  @typeCode='AUT'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'AUT' bevatten</assert>
            <assert role="error" test="not(@contextControlCode) or  @contextControlCode='AP'"
                ><name path=".."/>/<name/>/@contextControlCode moet, indien anwezig, 'AP' bevatten</assert>
        </rule>
        
        <!-- ActRelationships -->
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:component1">
            <assert role="error" test="not(@typeCode) or  @typeCode='COMP'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'COMP' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='true'"
                ><name path=".."/>/<name/>/@contextConductionInd moet, indien aanwezig, 'true' bevatten</assert>
        </rule>
        
        <!-- EpisodeOfCare -->
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:component2">
            <assert role="error" test="not(@typeCode) or  @typeCode='COMP'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'COMP' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='true'"
                ><name path=".."/>/<name/>/@contextConductionInd moet, indien aanwezig, 'true' bevatten</assert>
        </rule>
        
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:reason">
            <assert role="error" test="not(@typeCode) or  @typeCode='RSON'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'RSON' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='true'"
                ><name path=".."/>/<name/>/@contextConductionInd moet, indien aanwezig, 'true' bevatten</assert>
        </rule>
    </pattern>
    
    <!-- episodeOfCondition Diagnose -->
    <pattern is-a="COCT_MT120100NL" id="REPC_IN990003NL-COCT_MT120100NL-Probleemlijst">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:reason/hl7:ObservationDx"/>
    </pattern>
    
    <!-- episodeOfCondition episodOfCare -->
    <pattern>
        <title>Episodes, EpisodOfCare deel</title>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:component2/hl7:episodOfCare/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="(@root and @extension) or @nullFlavor"
                ><name path=".."/>/<name/>/@root en id/@extension moeten een waarde bevatten, tenzij id/@nullFlavor een waarde bevat</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:component2/hl7:episodOfCare/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='active' or @code='completed'"
                ><name path=".."/>/<name/>/@code moet 'active' of 'completed' bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:component2/hl7:episodOfCare/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                ><name path=".."/>/<name/>/low/@value moet de startdatum bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:component2/hl7:episodOfCare/hl7:component">
            <assert role="error" test="not(@typeCode) or  @typeCode='COMP'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'COMP' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='false'"
                ><name path=".."/>/<name/>/@contextConductionInd moet, indien aanwezig, 'false' bevatten</assert>
        </rule>
    </pattern>
    
    <!-- episodeOfCondition episodOfCare actReference -->
    <pattern>
        <title>ActReference</title>
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:component2/hl7:episodOfCare/hl7:component/hl7:actReference">
            <let name="actRefRoot" value="hl7:id/@root"/>
            <let name="actRefExt" value="hl7:id/@extension"/>
            <let name="elementNameRef" value="if (ancestor::hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:*[hl7:id/@root=$actRefRoot and hl7:id/@extension=$actRefExt]) then (
                (ancestor::hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:*[hl7:id/@root=$actRefRoot and hl7:id/@extension=$actRefExt])[1]/local-name() ) else (
                (ancestor::hl7:PrimaryCareProvision/hl7:component2/hl7:*[hl7:id/@root=$actRefRoot and hl7:id/@extension=$actRefExt])[1]/local-name()
                )"/>
            
            <let name="refClass" value="if (string-length($elementNameRef)>0) then (
                if ($elementNameRef = 'JournalEntry' or $elementNameRef = 'ObservationDx' or $elementNameRef = 'observation' or $elementNameRef = 'Observation') then ('OBS') else (
                    if ($elementNameRef = 'ProcedureEvent') then ('PROC') else (
                        if ($elementNameRef = 'Referral') then ('PCPR') else (
                            if ($elementNameRef = 'MedicationDispenseEvent') then ('SPLY') else (
                                if ($elementNameRef = 'Prescription') then ('SBADM') else ('')
                            )
                        )
                    )
                )
            ) else ('')"/>
            <let name="refMood" value="if (string-length($refClass)>0) then (
                if ($elementNameRef = 'Prescription') then ('RQO') else ('EVN')
            ) else ('')"/>
            
            <assert role="error" test="not(@classCode) or string-length($refClass)=0 or @classCode=$refClass"
                ><name/>/@classCode '<value-of select="@classCode"/>' is niet gelijk aan de <value-of select="$elementNameRef"/>/@classCode '<value-of select="$refClass"/>' waarnaar wordt verwezen.</assert>
            <assert role="error" test="not(@moodCode) or string-length($refMood)=0 or @moodCode=$refMood"
                ><name/>/@moodCode '<value-of select="@moodCode"/>' is niet gelijk aan de <value-of select="$elementNameRef"/>/@moodCode '<value-of select="$refMood"/>' waarnaar wordt verwezen.</assert>
        </rule>
            
        <rule context="hl7:PrimaryCareProvision/hl7:component3/hl7:episodeOfCondition/hl7:component2/hl7:episodOfCare/hl7:component/hl7:actReference/hl7:id">
            <extends rule="II"/>
            <let name="actRefRoot" value="@root"/>
            <let name="actRefExt" value="@extension"/>
            <assert role="error"
                test="ancestor::hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/*/hl7:id[@root=$actRefRoot and @extension=$actRefExt] or
                ancestor::hl7:PrimaryCareProvision/hl7:component2/*/hl7:id[@root=$actRefRoot and @extension=$actRefExt]"
                >actReference/id verwijst niet naar een activiteit in deze interactie onder component1 of component2</assert>
        </rule>
    </pattern>
    
    <!-- encounter -->
    <pattern>
        <title>Consulten</title>
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter">
            <assert role="error" test="not(@classCode) or @classCode='ENC'"
                ><name/>/@classCode moet, indien anwezig, 'ENC' bevatten</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='EVN'"
                ><name/>/@moodCode moet, indien anwezig, 'EVN' bevatten</assert>
            
            <assert role="error" test="hl7:code"
                ><name/>/code is verplicht</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root and @extension"
                ><name path=".."/>/<name/> moet @root en @extension bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:effectiveTime">
            <extends rule="IVL_TS"/>
            <assert role="error" test="hl7:low/@value"
                ><name path=".."/>/<name/>/low moet de startdatum(tijd) bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:code">
            <extends rule="CV"/>
            <assert role="error" test="@code or @nullFlavor='UNK' or @nullFlavor='OTH'"
                ><name path=".."/>/<name/>/@code moet een waarde bevatten of @nullFlavor moet de waarde 'UNK' of 'OTH' bevatten.</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.30.14' or @nullFlavor"
                ><name path=".."/>/<name/>/@codeSystem moet '2.16.840.1.113883.2.4.4.30.14' (NHG tabel 14) bevatten of @nullFlavor is verplicht.</assert>
            <assert role="error" test="string-length(normalize-space(@displayName)) &gt; 0 or @nullFlavor"
                ><name path=".."/>/<name/>/@displayName moet een waarde bevatten of @nullFlavor is verplicht.</assert>
        </rule>
        
        <!-- participations -->
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:author">
            <assert role="error" test="not(@typeCode) or  @typeCode='AUT'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'AUT' bevatten</assert>
            <assert role="error" test="not(@contextControlCode) or  @contextControlCode='OP'"
                ><name path=".."/>/<name/>/@contextControlCode moet, indien anwezig, 'OP' bevatten</assert>
        </rule>
        
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:dataEnterer">
            <assert role="error" test="not(@typeCode) or  @typeCode='ENT'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'ENT' bevatten</assert>
            <assert role="error" test="not(@contextControlCode) or  @contextControlCode='OP'"
                ><name path=".."/>/<name/>/@contextControlCode moet, indien anwezig, 'OP' bevatten</assert>
        </rule>
        
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:performer">
            <assert role="error" test="not(@typeCode) or  @typeCode='PRF'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'PRF' bevatten</assert>
            <assert role="error" test="not(@contextControlCode) or  @contextControlCode='OP'"
                ><name path=".."/>/<name/>/@contextControlCode moet, indien anwezig, 'OP' bevatten</assert>
        </rule>
        
        <!-- ActRelationships -->
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component">
            <assert role="error" test="not(@typeCode) or  @typeCode='COMP'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'COMP' bevatten</assert>
            <assert role="error" test="not(@contextConductionInd) or @contextConductionInd='true'"
                ><name path=".."/>/<name/>/@contextConductionInd moet, indien aanwezig, 'true' bevatten</assert>
            
            <assert role="warning" test="hl7:sequenceNumber"
                >Waarschuwing: <name path=".."/>/<name/> bevat geen sequenceNumber</assert>
    	</rule>
        
        <rule context="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:sequenceNumber">
            <extends rule="INT"/>
        </rule>
    </pattern>
    
    <!-- pertinentAnnotationObsEvent -->
    <pattern>
        <title>Attentieregels</title>
        <rule context="hl7:PrimaryCareProvision/hl7:pertinentInformation/hl7:pertinentAnnotationObsEvent">
            <assert role="error" test="not(@classCode) or @classCode='OBS'"
                ><name/>/@classCode moet, indien anwezig, 'OBS' bevatten</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='EVN'"
                ><name/>/@moodCode moet, indien anwezig, 'EVN' bevatten</assert>
            
            <assert role="error" test="hl7:text"
                ><name/>/text is verplicht</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:pertinentInformation/hl7:pertinentAnnotationObsEvent/hl7:code">
            <extends rule="CV"/>
            <assert role="error" test="@code='ATT' or @code='SOC' or @code='SOS' or @code='WNN'"
                ><name path=".."/>/<name/>/@code moet 'ATT', 'SOC', 'SOS' of 'WNN' bevatten</assert>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.5.4'"
                ><name path=".."/>/<name/>/@codeSystem moet '2.16.840.1.113883.5.4' (ActCode) bevatten</assert>
        </rule>
        <rule context="hl7:PrimaryCareProvision/hl7:pertinentInformation/hl7:pertinentAnnotationObsEvent/hl7:text">
            <extends rule="ST"/>
            <assert role="error" test="string-length(normalize-space(.))>0"
                ><name path=".."/>/<name/> moet een waarde bevatten</assert>
        </rule>
        
        <!-- participations -->
        <rule context="hl7:PrimaryCareProvision/hl7:pertinentInformation/hl7:pertinentAnnotationObsEvent/hl7:author">
            <assert role="error" test="not(@typeCode) or  @typeCode='AUT'"
                ><name path=".."/>/<name/>/@typeCode moet, indien anwezig, 'AUT' bevatten</assert>
            <assert role="error" test="not(@contextControlCode) or  @contextControlCode='OP'"
                ><name path=".."/>/<name/>/@contextControlCode moet, indien anwezig, 'OP' bevatten</assert>
        </rule>
    </pattern>
    
    <!-- CMETs in Activities ChoiceBox -->
    <!-- Journaalregels -->
    <pattern is-a="COCT_MT120000NL_JE" id="REPC_IN990003NL-COCT_MT120000NL_JE-Encounter">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:JournalEntry"/>
    </pattern>
    <pattern is-a="COCT_MT120000NL_JE" id="REPC_IN990003NL-COCT_MT120000NL_JE">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component2/hl7:JournalEntry"/>
    </pattern>
    <!-- Diagnoses -->
    <pattern is-a="COCT_MT120100NL" id="REPC_IN990003NL-COCT_MT120100NL-Encounter">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:ObservationDx"/>
    </pattern>
    <pattern is-a="COCT_MT120100NL" id="REPC_IN990003NL-COCT_MT120100NL">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component2/hl7:ObservationDx"/>
    </pattern>
    <!-- Medicatieverstrekkingen -->
    <pattern is-a="COCT_MT924000NL" id="REPC_IN990003NL-COCT_MT924000NL-Encounter">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:MedicationDispenseEvent"/>
    </pattern>
    <pattern is-a="COCT_MT924000NL" id="REPC_IN990003NL-COCT_MT924000NL">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component2/hl7:MedicationDispenseEvent"/>
    </pattern>
    <!-- Medicatievoorschriften -->
    <pattern is-a="COCT_MT932000NL" id="REPC_IN990003NL-COCT_MT932000NL-Encounter">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:Prescription"/>
    </pattern>
    <pattern is-a="COCT_MT932000NL" id="REPC_IN990003NL-COCT_MT932000NL">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component2/hl7:Prescription"/>
    </pattern>
    <!-- Therapie -->
    <pattern is-a="COCT_MT990004NL" id="REPC_IN990003NL-COCT_MT990004NL-Encounter">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:ProcedureEvent"/>
    </pattern>
    <pattern is-a="COCT_MT990004NL" id="REPC_IN990003NL-COCT_MT990004NL">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component2/hl7:ProcedureEvent"/>
    </pattern>
    <!-- Laboratoriumuitslagen -->
    <pattern is-a="REPC_MT000100UV01-Observation" id="REPC_IN990003NL-REPC_MT000100UV01-Observation-Encounter">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:observation"/>
        <param name="ucumList" value="$ucumList"/>
    </pattern>
    <pattern is-a="REPC_MT000100UV01-Observation" id="REPC_IN990003NL-REPC_MT000100UV01-Observation">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component2/hl7:observation"/>
        <param name="ucumList" value="$ucumList"/>
    </pattern>
    <!-- Verwijzingen -->
    <pattern is-a="COCT_MT990001NL" id="REPC_IN990003NL-QUCT_MT990001NL-Encounter">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter/hl7:component/hl7:PatientCareProvisionRequest"/>
    </pattern>
    <pattern is-a="COCT_MT990001NL" id="REPC_IN990003NL-COCT_MT990001NL">
        <param name="element" value="hl7:PrimaryCareProvision/hl7:component2/hl7:PatientCareProvisionRequest"/>
    </pattern>
</schema>
