<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Implementatiehandleiding HL7v3 Basiscomponenten, v2.2 - Datatype 1.0 SXPR_TS - Parenthetic Set Expression
    Status: in behandeling
-->
<rule abstract="true" id="SXPR_TS" see="http://hl7book.net/index.php?title=DatatypesR1:SXPR_TS" xmlns="http://purl.oclc.org/dsdl/schematron">
    <extends rule="QTY"/>
    
    <assert role="error" test="@nullFlavor or count(hl7:comp) >= 2"
        >Datatype SXPR_TS: null or at least two components</assert>
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='SXPR_TS']) or 
        descendant::hl7:comp[@xsi:type='SXPR_TS' and @nullFlavor] or 
        descendant::hl7:comp[@xsi:type='SXPR_TS' and count(hl7:comp) >= 2]"
        >Datatype SXPR_TS: null or at least two components</assert>
    <assert role="error" test="count(descendant::hl7:*[@updateMode])=0"
        >Datatype SXPR_TS: no updateMode on components or other subelements</assert>
    
    <!-- comp type IVL_TS -->
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='IVL_TS']) or
        (descendant::hl7:comp[@xsi:type='IVL_TS' and @nullFlavor and not(@value|@unit|*)]) or 
        (descendant::hl7:comp[@xsi:type='IVL_TS' and not(@nullFlavor) and (@value|@unit|*)])"
        >Datatype SXPR_TS/IVL: null violation. Cannot have @nullFlavor and @value or child elements, or the other way around</assert>
    <assert role="error" test="
        not(descendant::hl7:comp[@xsi:type='IVL_TS']/*) or
        descendant::hl7:comp[@xsi:type='IVL_TS' and @nullFlavor] or
        descendant::hl7:comp[@xsi:type='IVL_TS' and not(@nullFlavor) and @value and not(*)] or
        descendant::hl7:comp[@xsi:type='IVL_TS' and not(@nullFlavor) and not(@value)]/*[@nullFlavor] or
        descendant::hl7:comp[@xsi:type='IVL_TS' and not(@nullFlavor) and not(@value)]/*[not(@nullFlavor) and not(hl7:center and (hl7:low|hl7:high|hl7:width))] or
        descendant::hl7:comp[@xsi:type='IVL_TS' and not(@nullFlavor) and not(@value)]/*[not(@nullFlavor) and not(hl7:center) and not(hl7:width and (hl7:low|hl7:high))]"
        >Datatype SXPR_TS/SXCM: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, 
        or center element with other elements, or width element with both low and high elements</assert>
    
    <assert role="error" test="
        not(descendant::hl7:comp[@xsi:type='IVL_TS' and hl7:low/@value and hl7:high/@value]) or 
        descendant::hl7:comp[@xsi:type='IVL_TS' and string-length(hl7:low/@value) = string-length(hl7:high/@value)]"
        >Datatype SXPR_TS/IVL_TS: waarde in comp/low/@value moet dezelfde precisie hebben als comp/high/@value</assert>
    
    <!-- width has datatype PQR, which extends CV ((){1}(((0[1-9])|([12]\d)|(3[01]))?)?)? -->
    <assert role="error"
        test="not(descendant::hl7:comp[@xsi:type='IVL_TS']/hl7:width) or
        descendant::hl7:comp[@xsi:type='IVL_TS']/hl7:width[not(@unit)] or
        descendant::hl7:comp[@xsi:type='IVL_TS']/hl7:width[@value and @unit]"
        >Datatype SXPR_TS/IVL_TS/PQR: width element: no unit without value</assert>
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='IVL_TS']/hl7:width/hl7:translation)"
        >Datatype SXPR_TS/IVL_TS/PQR: width element: no translation</assert>
    
    <!-- comp type PIVL_TS -->
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='PIVL_TS']) or
        descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:period[@nullFlavor and not(@value)] or
        descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:period[not(@nullFlavor) and @value]"
        >Datatype SXPR_TS/PIVL_TS/PQ: null or value in period</assert>
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='PIVL_TS']) or
        not(descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:period[@nullFlavor]/hl7:translation) or
        descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:period[not(@nullFlavor)]/hl7:translation"
        >Datatype SXPR_TS/PIVL_TS/PQ: no translation if null in period</assert>
    
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='PIVL_TS']) or
        (descendant::hl7:comp[@xsi:type='PIVL_TS' and @nullFlavor and not(@value|@unit|*)]) or 
        (descendant::hl7:comp[@xsi:type='PIVL_TS' and not(@nullFlavor) and (@value|@unit|*)])"
        >Datatype SXPR_TS/PIVL_TS: null violation. Cannot have @nullFlavor and @value or child elements, or the other way around</assert>
    <assert role="error" test="
        not(descendant::hl7:comp[@xsi:type='PIVL_TS']/*) or
        descendant::hl7:comp[@xsi:type='PIVL_TS' and @nullFlavor] or
        descendant::hl7:comp[@xsi:type='PIVL_TS' and not(@nullFlavor) and @value and not(*)] or
        descendant::hl7:comp[@xsi:type='PIVL_TS' and not(@nullFlavor) and not(@value)]/*[@nullFlavor] or
        descendant::hl7:comp[@xsi:type='PIVL_TS' and not(@nullFlavor) and not(@value)]/*[not(@nullFlavor) and not(hl7:center and (hl7:low|hl7:high|hl7:width))] or
        descendant::hl7:comp[@xsi:type='PIVL_TS' and not(@nullFlavor) and not(@value)]/*[not(@nullFlavor) and not(hl7:center) and not(hl7:width and (hl7:low|hl7:high))]"
        >Datatype SXPR_TS/PIVL_TS: co-occurence violation. Cannot have @value and other child elements, or missing @value and child elements with data, 
        or center element with other elements, or width element with both low and high elements</assert>
    <assert role="error" test="
        not(descendant::hl7:comp[@xsi:type='PIVL_TS' and hl7:low/@value and hl7:high/@value]) or 
        descendant::hl7:comp[@xsi:type='PIVL_TS' and string-length(hl7:low/@value) = string-length(hl7:high/@value)]"
        >Datatype SXPR_TS/PIVL_TS: waarde in comp/low/@value moet dezelfde precisie hebben als comp/high/@value</assert>
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:period[string-length(substring-after(@value,'.')) &gt; 4])"
        >Datatype SXPR_TS/PIVL_TS: waarde in period/@value moet zijn afgerond op 4 decimalen of minder</assert>
    
    <!-- width has datatype PQR, which extends CV ((){1}(((0[1-9])|([12]\d)|(3[01]))?)?)? -->
    <assert role="error"
        test="not(descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:width) or
        descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:width[not(@unit)] or
        descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:width[@value and @unit]"
        >Datatype SXPR_TS/PIVL_TS/PQR: width element: no unit without value</assert>
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='PIVL_TS']/hl7:width/hl7:translation)"
        >Datatype SXPR_TS/PIVL_TS/PQR: width element: no translation</assert>
    
    <!-- EIVL_TS -->
    <assert role="error" test="not(descendant::hl7:comp[@xsi:type='EIVL_TS'])"
        >Datatype SXPR_TS/EIVL_TS: dit datatype is in Nederland nog niet toegestaan</assert>
</rule>