<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
   <title>Schematronvalidatie van REPC_IN002120NL_JGZ - JGZ Dossier Overdracht</title>
   <ns uri="urn:hl7-org:v3" prefix="hl7"/>
   <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
   <include href="coreschematron/xml.sch"/>
   <include href="coreschematron/attentionLine.sch"/>
   
   <include href="coreschematron/transmission-wrapper.sch"/>
   <include href="coreschematron/controlAct-wrapper.sch"/>
   
   <pattern is-a="attentionLine" id="REPC_IN002120NL_JGZ-attentionLine">
      <param name="messagePatientId"
             value="hl7:ControlActProcess/hl7:subject/hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:id"/>
      <param name="attentionLineOptional" value="'false'"/>
   </pattern>
   
   <pattern is-a="transmission-wrapper" id="REPC_IN002120NL_JGZ-wrapper">
      <param name="element" value="hl7:REPC_IN002120NL_JGZ"/>
   </pattern>
   
   <pattern is-a="controlAct-wrapper" id="REPC_IN002120NL_JGZ-controlAct">
      <param name="element" value="hl7:REPC_IN002120NL_JGZ/hl7:ControlActProcess"/>
   </pattern>
   
   <pattern>
      <!-- profileId -->
      <rule context="hl7:REPC_IN002120NL_JGZ/hl7:profileId">
         <extends rule="II"/>
         <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
            >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
      </rule>
      <rule context="hl7:REPC_IN002120NL_JGZ/hl7:acceptAckCode">
         <extends rule="CS"/>
         <assert role="error" test="@code='AL'">In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'AL'.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Codes algemeen</title>
      <rule context="hl7:code">
         <assert test="(@code and @codeSystem) or @nullFlavor or @xsi:nil='true'">Code elementen moeten een
                        code en codesystem attribuut bevatten of een nullfavor.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Bijzonderheden gezin</title>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:subjectOf/hl7:personalRelationshipObservation">
         <assert test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem
                        moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert test="hl7:code/@code='78' or hl7:code/@code='1322' or hl7:code/@code='1367' or hl7:code/@code='1374'">De waarde van code/@code moet 78, 1367 of 1374 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Persoonsgegevens</title>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:subjectOf/hl7:AdministrativeObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:subjectOf/hl7:AdministrativeObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:member/hl7:group">
         <assert role="error"
                 test="not(hl7:id) or substring(hl7:id/@root,1,20)='2.16.528.1.1007.3.3.'">De OID van id/@root moet beginnen met 2.16.528.1.1007.3.3.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Verantwoordelijke JGZ-organisatie</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:author/hl7:assignedEntity">
         <assert role="error" test="hl7:id/@root='2.16.528.1.1007.3.3'">De OID van id/@root moet 2.16.528.1.1007.3.3 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:author/hl7:assignedEntity">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1'">De OID van id/@root moet 2.16.528.1.1007.3.1 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Huisarts</title>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:patientOfOtherProvider/hl7:subjectOf/hl7:CareProvision/hl7:performer/hl7:AssignedProvider">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1'">De OID van id/@root moet 2.16.528.1.1007.3.1 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:patientOfOtherProvider/hl7:subjectOf/hl7:CareProvision/hl7:performer/hl7:AssignedPerformer/hl7:Organization">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.3'">De OID van id/@root moet 2.16.528.1.1007.3.3 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Andere betrokken organisaties/hulpverleners</title>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:patientOfOtherProvider/hl7:subjectOf/hl7:CareProvision/hl7:performer/hl7:AssignedProvider">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1'">De OID van id/@root moet 2.16.528.1.1007.3.1 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:patientOfOtherProvider/hl7:subjectOf/hl7:CareProvision/hl7:performer/hl7:AssignedPerformer/hl7:Organization">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.3'">De OID van id/@root moet 2.16.528.1.1007.3.3 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Voor- of buitenschoolse voorzieningen/school</title>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:Student/hl7:Organization">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.840.1.113883.2.4.6.15'">De OID van id/@root moet 2.16.840.1.113883.2.4.6.15 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Gezinssamenstelling</title>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:subjectOf/hl7:personalRelationshipObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='1367'">De waarde van code/@code moet 1367 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:person">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.840.1.113883.2.4.6.3'">De OID van id/@root moet 2.16.840.1.113883.2.4.6.3 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:person/hl7:houseMate/hl7:group">
         <assert role="error"
                 test="not(hl7:id) or substring(hl7:id/@root,1,20)='2.16.528.1.1007.3.3.'">De OID van id/@root moet beginnen met 2.16.528.1.1007.3.3.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:subjectOf/hl7:personalRelationshipObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='78'">De waarde van code/@code moet 78 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:person/hl7:houseMate/hl7:group">
         <assert role="error"
                 test="not(hl7:id) or substring(hl7:id/@root,1,20)='2.16.528.1.1007.3.3.'">De OID van id/@root moet beginnen met 2.16.528.1.1007.3.3.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:member/hl7:subjectOf/hl7:observation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='1190'">De waarde van code/@code moet 1190 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:member/hl7:group">
         <assert role="error" test="substring(hl7:id/@root,1,20)='2.16.528.1.1007.3.3.'">De OID van id/@root moet beginnen met 2.16.528.1.1007.3.3.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:subjectOf/hl7:personalRelationshipObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='1374'">De waarde van code/@code moet 1374 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:subject/hl7:patient/hl7:patientPerson/hl7:personalRelationship/hl7:person/hl7:houseMate/hl7:group">
         <assert role="error"
                 test="not(hl7:id) or substring(hl7:id/@root,1,20)='2.16.528.1.1007.3.3.'">De OID van id/@root moet beginnen met 2.16.528.1.1007.3.3.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Erfelijke belasting en ouderkenmerken</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R012']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=79])&gt;=1">Element 79, 'Erfelijke belasting en ouderkenmerken nagevraagd' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='79']"
            id="BDS79">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='238']"
            id="BDS238">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='240']"
            id="BDS240">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='808']"
            id="BDS808">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='241']"
            id="BDS241">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.29'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.29 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='239']"
            id="BDS239">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.29'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.29 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='80']"
            id="BDS80">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.8' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.8 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='70']"
            id="BDS70">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.5' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.5 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Bedreigingen uit de directe omgeving</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R013']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error"
                 test="count(hl7:component/hl7:observation[hl7:code/@code=1384])&gt;=1">Element 1384, 'Bedreigingen nagevraagd' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1384']"
            id="BDS1384">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1415']"
            id="BDS1415">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1416']"
            id="BDS1416">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='481']"
            id="BDS481">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.81' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.81 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='827']"
            id="BDS827">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.305' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.305 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='739']"
            id="BDS739">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.396'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.396 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1414']"
            id="BDS1414">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.405' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.405 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Zwangerschap</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:component1/hl7:PregnancyObservations">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='82'">De waarde van code/@code moet 82 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:component1/hl7:PregnancyObservations">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='91'">De waarde van code/@code moet 91 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:component1/hl7:PregnancyObservations">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='92'">De waarde van code/@code moet 92 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:component1/hl7:PregnancyObservations">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='93'">De waarde van code/@code moet 93 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:component1/hl7:PregnancyObservations">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='741'">De waarde van code/@code moet 741 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:component1/hl7:PregnancyObservations">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='740'">De waarde van code/@code moet 740 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:component1/hl7:PregnancyObservations">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='619'">De waarde van code/@code moet 619 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:component1/hl7:PregnancyObservations/hl7:component/hl7:DetailPregnancyObservation">
         <assert role="error" test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.306'">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.306 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='745'">De waarde van code/@code moet 745 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Bevalling</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='1323'">De waarde van code/@code moet 1323 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='98'">De waarde van code/@code moet 98 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='97'">De waarde van code/@code moet 97 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='105'">De waarde van code/@code moet 105 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='106'">De waarde van code/@code moet 106 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='107'">De waarde van code/@code moet 107 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='1324'">De waarde van code/@code moet 1324 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.167'">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.167 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='100'">De waarde van code/@code moet 100 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:pertinentInformation/hl7:pregnancyCondition/hl7:outcome/hl7:Delivery/hl7:component/hl7:DeliveryObservation">
         <assert role="error" test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.170'">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.170 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='103'">De waarde van code/@code moet 103 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Pasgeborene en eerste levensweken</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='108']"
            id="BDS108">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='110']"
            id="BDS110">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='111']"
            id="BDS111">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='113']"
            id="BDS113">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='112']"
            id="BDS112">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='129']"
            id="BDS129">
         <assert role="error" test="hl7:value/@xsi:type='INT'">Het datatype van value moet INT zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='130']"
            id="BDS130">
         <assert role="error" test="hl7:value/@xsi:type='INT'">Het datatype van value moet INT zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='131']"
            id="BDS131">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='133']"
            id="BDS133">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='134']"
            id="BDS134">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='135']"
            id="BDS135">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='139']"
            id="BDS139">
         <assert role="error" test="hl7:value/@xsi:type='IVL&lt;TS&gt;'">Het datatype van value moet IVL&lt;TS&gt; zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component1/hl7:InPatientEncounter/hl7:location/hl7:ServiceDeliveryLocation/hl7:locationOf/hl7:IncubatorAccomodation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='144'">De waarde van code/@code moet 144 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='145']"
            id="BDS145">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='626']"
            id="BDS626">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='115']"
            id="BDS115">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='747']"
            id="BDS747">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.307' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.307 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='1340']"
            id="BDS1340">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.307' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.307 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='140']"
            id="BDS140">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.174' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.174 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component2/hl7:neonateData/hl7:NeonateData/hl7:component4/hl7:NeonateObservations[hl7:code/@code='142']"
            id="BDS142">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.154' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.154 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Activiteit</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/hl7:EncounterEvent">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.308'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.308 zijn.</assert>
         <assert role="error" test="hl7:reasonCode/@codeSystem='2.16.840.1.113883.2.4.4.40.373'">De OID van reasonCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.373 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Terugkerende anamnese</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R019']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=748])&gt;=1">Element 748, 'Anamnese' moet minimaal 1 keer voorkomen</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=148])&gt;=1">Element 148, 'Anamnese nagevraagd' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1412">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='149']"
            id="BDS149">
         <assert role="error" test="hl7:value/@xsi:type='INT'">Het datatype van value moet INT zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='150']"
            id="BDS150">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1337']"
            id="BDS1337">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1338']"
            id="BDS1338">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1339">
         <assert role="error" test="hl7:value/@xsi:type='ED'">Het datatype van value moet ED zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='748']"
            id="BDS748">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='753']"
            id="BDS753">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS754">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='752']"
            id="BDS752">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='148']"
            id="BDS148">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='153']"
            id="BDS153">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='154']"
            id="BDS154">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='155']"
            id="BDS155">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='322']"
            id="BDS322">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='323']"
            id="BDS323">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='330']"
            id="BDS330">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='152']"
            id="BDS152">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='496']"
            id="BDS496">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.307' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.307 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='514']"
            id="BDS514">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.99' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.99 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='510']"
            id="BDS510">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.97' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.97 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='755']"
            id="BDS755">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.400' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.400 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='179']"
            id="BDS179">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.315' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.315 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='188']"
            id="BDS188">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.15' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.15 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='190']"
            id="BDS190">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.16' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.16 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1378']"
            id="BDS1378">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.389' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.389 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Algemene indruk</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R020']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=756])&gt;=1">Element 756, 'Algemene indruk verkregen' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='756']"
            id="BDS756">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='757']"
            id="BDS757">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='758']"
            id="BDS758">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='759']"
            id="BDS759">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='760']"
            id="BDS760">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='761']"
            id="BDS761">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='762']"
            id="BDS762">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='763']"
            id="BDS763">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:targetSiteCode">Er moet een element 'targetSiteCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='766']"
            id="BDS766">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='767']"
            id="BDS767">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='768']"
            id="BDS768">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS764">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.13'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.13 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='765']"
            id="BDS765">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.311' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.311 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Functioneren</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R021']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=772])&gt;=1">Element 772, 'Adaptatie/persoonlijkheid/sociaal gedrag nagevraagd' moet minimaal 1 keer voorkomen</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=787])&gt;=1">Element 787, 'Functioneren op school nagevraagd' moet minimaal 1 keer voorkomen</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=321])&gt;=1">Element 321, 'Lichamelijk functioneren nagevraagd' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='770']"
            id="BDS770">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='772']"
            id="BDS772">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='773']"
            id="BDS773">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='774']"
            id="BDS774">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='775']"
            id="BDS775">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='776']"
            id="BDS776">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='777']"
            id="BDS777">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='778']"
            id="BDS778">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='779']"
            id="BDS779">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='780']"
            id="BDS780">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='781']"
            id="BDS781">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='782']"
            id="BDS782">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='783']"
            id="BDS783">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='784']"
            id="BDS784">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS786">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='787']"
            id="BDS787">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='790']"
            id="BDS790">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='791']"
            id="BDS791">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='792']"
            id="BDS792">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='321']"
            id="BDS321">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='325']"
            id="BDS325">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='328']"
            id="BDS328">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='324']"
            id="BDS324">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.46' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.46 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='771']"
            id="BDS771">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.312' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.312 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='785']"
            id="BDS785">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.313' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.313 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1422">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.409' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.409 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Huid/haar/nagels</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R022']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=161])&gt;=1">Element 161, 'Huid/haar/nagels onderzocht' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='161']"
            id="BDS161">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='164']"
            id="BDS164">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='163']"
            id="BDS163">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.263' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.263 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Hoofd/hals</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R023']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
      	<assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=161])&gt;=1">Element 161, 'Huid/haar/nagels' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='167']"
            id="BDS167">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='176']"
            id="BDS176">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='184']"
            id="BDS184">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='794']"
            id="BDS794">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.314' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.314 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='795']"
            id="BDS795">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.314' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.314 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='174']"
            id="BDS174">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.10' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.10 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='175']"
            id="BDS175">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.10' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.10 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='796']"
            id="BDS796">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.316' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.316 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='797']"
            id="BDS797">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.317' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.317 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='193']"
            id="BDS193">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.12' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.12 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS793">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.13'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.13 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='170']"
            id="BDS170">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.11' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.11 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:targetSiteCode">Er moet een element 'targetSiteCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Romp</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R024']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=167])&gt;=1">Element 167, 'Hoofd/hals' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='798']"
            id="BDS798">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='196']"
            id="BDS196">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='201']"
            id="BDS201">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.318' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.318 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='202']"
            id="BDS202">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.19' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.19 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='209']"
            id="BDS209">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.20' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.20 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='210']"
            id="BDS210">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.319' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.319 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='211']"
            id="BDS211">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.319' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.319 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Bewegingsapparaat</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R025']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=212])&gt;=1">Element 212, 'Bewegingsapparaat onderzocht' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='212']"
            id="BDS212">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='800']"
            id="BDS800">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='804']"
            id="BDS804">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS801">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.13'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.13 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='218']"
            id="BDS218">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.21' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.21 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='805']"
            id="BDS805">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.321' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.321 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='223']"
            id="BDS223">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.321' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.321 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='802']"
            id="BDS802">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:targetSiteCode">Er moet een element 'targetSiteCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS803">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.13'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.13 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS220">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.13'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.13 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='219']"
            id="BDS219">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.22' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.22 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:targetSiteCode">Er moet een element 'targetSiteCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS222">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.13'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.13 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='221']"
            id="BDS221">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.23' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.23 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:targetSiteCode">Er moet een element 'targetSiteCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS799">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.13'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.13 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='217']"
            id="BDS217">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.320' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.320 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:targetSiteCode">Er moet een element 'targetSiteCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Genitalia/puberteitsontwikkeling</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R026']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=225])&gt;=1">Element 225, 'Genitalia/puberteitsontwikkeling onderzocht' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='806']"
            id="BDS806">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='807']"
            id="BDS807">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='824']"
            id="BDS824">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='225']"
            id="BDS225">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS228">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='312']"
            id="BDS312">
         <assert role="error" test="hl7:value/@xsi:type='TS'">Het datatype van value moet TS zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='230']"
            id="BDS230">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.24' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.24 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='232']"
            id="BDS232">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.26' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.26 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='422']"
            id="BDS422">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.72' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.72 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1392']"
            id="BDS1392">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.72' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.72 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1393']"
            id="BDS1393">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.27' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.27 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='233']"
            id="BDS233">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.27' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.27 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='313']"
            id="BDS313">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.43' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.43 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS314">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.34'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.34 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS316">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.34'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.34 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS318">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.34'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.34 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS826">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.34'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.34 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='315']"
            id="BDS315">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.44' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.44 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='825']"
            id="BDS825">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.44' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.44 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='317']"
            id="BDS317">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.45' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.45 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Groei</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R027']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='234']"
            id="BDS234">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='235']"
            id="BDS235">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='252']"
            id="BDS252">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='245']"
            id="BDS245">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='236']"
            id="BDS236">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.28'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.28 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='246']"
            id="BDS246">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.30'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.30 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='247']"
            id="BDS247">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.31' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.31 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Psychosociale en cognitieve ontwikkeling</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R030']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=259])&gt;=1">Element 259, 'Psychosociale en cognitieve ontwikkeling onderzocht' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS814">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='259']"
            id="BDS259">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='265']"
            id="BDS265">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Motorische ontwikkeling</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R031']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=268])&gt;=1">Element 268, 'Motorische ontwikkeling onderzocht' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='268']"
            id="BDS268">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='271']"
            id="BDS271">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='276']"
            id="BDS276">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='269']"
            id="BDS269">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.35' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.35 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='815']"
            id="BDS815">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.322' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.322 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Spraak- en taalontwikkeling</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R032']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=294])&gt;=1">Element 294, 'Spraak- en taalontwikkeling onderzocht' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='817']"
            id="BDS817">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS819">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='818']"
            id="BDS818">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='821']"
            id="BDS821">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='822']"
            id="BDS822">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='294']"
            id="BDS294">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='301']"
            id="BDS301">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.40' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.40 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='820']"
            id="BDS820">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.326' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.326 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='823']"
            id="BDS823">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.327' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.327 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster[hl7:code/@code='G036']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.393'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.393 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=302])&gt;=1">Element 302, 'Taal' moet minimaal 1 keer voorkomen</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=307])&gt;=1">Element 307, 'Eerste/tweede taal' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='1329']"
            id="BDS1329">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='302']"
            id="BDS302">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.6.100' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.6.100 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='307']"
            id="BDS307">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.323' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.323 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='816']"
            id="BDS816">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.324' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.324 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Inschatten verhouding draaglast-draagkracht</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R034']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=339])&gt;=1">Element 339, 'Verhouding draaglast-draagkracht onderzocht' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS349">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='339']"
            id="BDS339">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='348']"
            id="BDS348">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.60' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.60 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Ontvangen zorg</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component3/hl7:patientCareProvision/hl7:reasonOf/hl7:patientCareObservation[hl7:code/@code='365']"
            id="BDS365">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component3/hl7:patientCareProvision/hl7:componentOf/hl7:patientCareObservation[hl7:code/@code='1201']"
            id="BDS1201">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Voorlichting, advies, instructie en begeleiding</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component2/hl7:Advice/hl7:component/hl7:Act">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='1157'">De waarde van code/@code moet 1157 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Oogonderzoek</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R038']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error"
                 test="count(hl7:component/hl7:observation[hl7:code/@code=1379])&gt;=1">Element 1379, 'Oogonderzoek uitgevoerd' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='832']"
            id="BDS832">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.329' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.329 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='833']"
            id="BDS833">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.330' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.330 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='834']"
            id="BDS834">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.330' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.330 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='835']"
            id="BDS835">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.331' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.331 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='836']"
            id="BDS836">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.331' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.331 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='837']"
            id="BDS837">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.332' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.332 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='838']"
            id="BDS838">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.332' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.332 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS839">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS842">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS851">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='853']"
            id="BDS853">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='854']"
            id="BDS854">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1379']"
            id="BDS1379">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='692']"
            id="BDS692">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.329' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.329 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='390']"
            id="BDS390">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='391']"
            id="BDS391">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='392']"
            id="BDS392">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='393']"
            id="BDS393">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='840']"
            id="BDS840">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='841']"
            id="BDS841">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='404']"
            id="BDS404">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='405']"
            id="BDS405">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='406']"
            id="BDS406">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='407']"
            id="BDS407">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='394']"
            id="BDS394">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='395']"
            id="BDS395">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='396']"
            id="BDS396">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='397']"
            id="BDS397">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='398']"
            id="BDS398">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='399']"
            id="BDS399">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='402']"
            id="BDS402">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='403']"
            id="BDS403">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='831']"
            id="BDS831">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.328' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.328 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='408']"
            id="BDS408">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.333' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.333 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='852']"
            id="BDS852">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.334' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.334 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1421']"
            id="BDS1421">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.407' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.407 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1418']"
            id="BDS1418">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.406' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.406 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1419']"
            id="BDS1419">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.406' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.406 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1420']"
            id="BDS1420">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.407' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.407 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Hartonderzoek</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R039']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=855])&gt;=1">Element 855, 'Hartonderzoek uitgevoerd' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS428">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='855']"
            id="BDS855">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='861']"
            id="BDS861">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='862']"
            id="BDS862">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='746']"
            id="BDS746">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='146']"
            id="BDS146">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='207']"
            id="BDS207">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.337' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.337 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='206']"
            id="BDS206">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.337' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.337 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster[hl7:code/@code='G044']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.393'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.393 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation)&gt;=1">Element 1202, 'Methode meting' moet minimaal 1 keer voorkomen</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=856])&gt;=1">Element 856, 'Geruis intensiteit' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='859']"
            id="BDS859">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='860']"
            id="BDS860">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1202">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.395'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.395 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='856']"
            id="BDS856">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.335' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.335 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:methodCode">Er moet een element 'methodCode' aanwezig zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:groupCluster/hl7:component/hl7:observation[hl7:code/@code='858']"
            id="BDS858">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.336' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.336 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Gehooronderzoek</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R040']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error" test="count(hl7:component/hl7:observation[hl7:code/@code=438])&gt;=1">Element 438, 'Gehooronderzoek uitgevoerd' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='863']"
            id="BDS863">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1413">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='438']"
            id="BDS438">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1203']"
            id="BDS1203">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1204']"
            id="BDS1204">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1205']"
            id="BDS1205">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1206']"
            id="BDS1206">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1207']"
            id="BDS1207">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1208']"
            id="BDS1208">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1209']"
            id="BDS1209">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1210']"
            id="BDS1210">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1211']"
            id="BDS1211">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1212']"
            id="BDS1212">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1213']"
            id="BDS1213">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1214']"
            id="BDS1214">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='865']"
            id="BDS865">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1239']"
            id="BDS1239">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='439']"
            id="BDS439">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='447']"
            id="BDS447">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='441']"
            id="BDS441">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='442']"
            id="BDS442">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='444']"
            id="BDS444">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='445']"
            id="BDS445">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='864']"
            id="BDS864">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.338' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.338 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1216']"
            id="BDS1216">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1238']"
            id="BDS1238">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1234']"
            id="BDS1234">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1236']"
            id="BDS1236">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1218']"
            id="BDS1218">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1220']"
            id="BDS1220">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1222']"
            id="BDS1222">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1224']"
            id="BDS1224">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1226']"
            id="BDS1226">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1228']"
            id="BDS1228">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1230']"
            id="BDS1230">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1232']"
            id="BDS1232">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.339' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.339 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Rijksvaccinatieprogramma en andere vaccinaties</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component3/hl7:SubstanceAdministrationEvent/hl7:causeOf/hl7:AdverseReaction/hl7:reason/hl7:InformationControlActEvent">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='875'">De waarde van code/@code moet 875 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component3/hl7:SubstanceAdministrationEvent/hl7:causeOf/hl7:AdverseReaction/hl7:reason/hl7:InformationControlActEvent/hl7:perfomer/hl7:AssignedPerson">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1'">De OID van id/@root moet 2.16.528.1.1007.3.1 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component3/hl7:SubstanceAdministrationEvent/hl7:causeOf/hl7:AdverseReaction">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='874'">De waarde van code/@code moet 874 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component1/hl7:VaccinationObservation">
         <assert role="error" test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.399'">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.399 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='608'">De waarde van code/@code moet 608 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component1/hl7:VaccinationObservation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='872'">De waarde van code/@code moet 872 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:reasonOf/hl7:VaccinationReason">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='686'">De waarde van code/@code moet 686 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component1/hl7:VaccinationObservation">
         <assert role="error" test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.402'">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.402 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component3/hl7:SubstanceAdministrationEvent/hl7:subjectOf/hl7:ScheduleDeviation">
         <assert role="error" test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.340'">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.340 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component3/hl7:SubstanceAdministrationEvent/hl7:subjectOf/hl7:ScheduleDeviation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='871'">De waarde van code/@code moet 871 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:component5/hl7:Vaccinations/hl7:component3/hl7:SubstanceAdministrationEvent/hl7:sourceOf/hl7:SerologyTest">
         <assert role="error" test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.325'">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.325 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Van Wiechen ontwikkelingsonderzoek</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R042']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='880']"
            id="BDS880">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='882']"
            id="BDS882">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='895']"
            id="BDS895">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='899']"
            id="BDS899">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='901']"
            id="BDS901">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='904']"
            id="BDS904">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='908']"
            id="BDS908">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='911']"
            id="BDS911">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='915']"
            id="BDS915">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='919']"
            id="BDS919">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='929']"
            id="BDS929">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='942']"
            id="BDS942">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='944']"
            id="BDS944">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='946']"
            id="BDS946">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='952']"
            id="BDS952">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='957']"
            id="BDS957">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='960']"
            id="BDS960">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='963']"
            id="BDS963">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='965']"
            id="BDS965">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='967']"
            id="BDS967">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='969']"
            id="BDS969">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='972']"
            id="BDS972">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='974']"
            id="BDS974">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='976']"
            id="BDS976">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='979']"
            id="BDS979">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='981']"
            id="BDS981">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='983']"
            id="BDS983">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='985']"
            id="BDS985">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='987']"
            id="BDS987">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='988']"
            id="BDS988">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='990']"
            id="BDS990">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='992']"
            id="BDS992">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='995']"
            id="BDS995">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='997']"
            id="BDS997">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1000']"
            id="BDS1000">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1003']"
            id="BDS1003">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1004']"
            id="BDS1004">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1240']"
            id="BDS1240">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1241']"
            id="BDS1241">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1242']"
            id="BDS1242">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1243']"
            id="BDS1243">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1244']"
            id="BDS1244">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1245']"
            id="BDS1245">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1246']"
            id="BDS1246">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1247']"
            id="BDS1247">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1248']"
            id="BDS1248">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1249']"
            id="BDS1249">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1250']"
            id="BDS1250">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1251']"
            id="BDS1251">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1252']"
            id="BDS1252">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1253']"
            id="BDS1253">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1254']"
            id="BDS1254">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1255']"
            id="BDS1255">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1256']"
            id="BDS1256">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1257']"
            id="BDS1257">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1258']"
            id="BDS1258">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1259']"
            id="BDS1259">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1260']"
            id="BDS1260">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1261']"
            id="BDS1261">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1262']"
            id="BDS1262">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1263']"
            id="BDS1263">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1264']"
            id="BDS1264">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1265']"
            id="BDS1265">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1266']"
            id="BDS1266">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1267']"
            id="BDS1267">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1268']"
            id="BDS1268">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1269']"
            id="BDS1269">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1270']"
            id="BDS1270">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1271']"
            id="BDS1271">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1272']"
            id="BDS1272">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1273']"
            id="BDS1273">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1274']"
            id="BDS1274">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1275']"
            id="BDS1275">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1276']"
            id="BDS1276">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1277']"
            id="BDS1277">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1280']"
            id="BDS1280">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1279']"
            id="BDS1279">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='881']"
            id="BDS881">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='879']"
            id="BDS879">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='883']"
            id="BDS883">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='884']"
            id="BDS884">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='885']"
            id="BDS885">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='888']"
            id="BDS888">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='889']"
            id="BDS889">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='887']"
            id="BDS887">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='890']"
            id="BDS890">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='903']"
            id="BDS903">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='906']"
            id="BDS906">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='902']"
            id="BDS902">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='896']"
            id="BDS896">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='897']"
            id="BDS897">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='898']"
            id="BDS898">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='891']"
            id="BDS891">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='894']"
            id="BDS894">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='968']"
            id="BDS968">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='970']"
            id="BDS970">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='971']"
            id="BDS971">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='966']"
            id="BDS966">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='964']"
            id="BDS964">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='962']"
            id="BDS962">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='961']"
            id="BDS961">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='956']"
            id="BDS956">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='958']"
            id="BDS958">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='959']"
            id="BDS959">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='955']"
            id="BDS955">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='951']"
            id="BDS951">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='945']"
            id="BDS945">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='926']"
            id="BDS926">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='920']"
            id="BDS920">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='922']"
            id="BDS922">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='916']"
            id="BDS916">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='917']"
            id="BDS917">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='918']"
            id="BDS918">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='912']"
            id="BDS912">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='914']"
            id="BDS914">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='907']"
            id="BDS907">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='910']"
            id="BDS910">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1002']"
            id="BDS1002">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1001']"
            id="BDS1001">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='996']"
            id="BDS996">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='999']"
            id="BDS999">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='994']"
            id="BDS994">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='993']"
            id="BDS993">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='991']"
            id="BDS991">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='989']"
            id="BDS989">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='986']"
            id="BDS986">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='978']"
            id="BDS978">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='977']"
            id="BDS977">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='975']"
            id="BDS975">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='877']"
            id="BDS877">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.341' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.341 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='878']"
            id="BDS878">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.342' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.342 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='886']"
            id="BDS886">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='893']"
            id="BDS893">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='892']"
            id="BDS892">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='900']"
            id="BDS900">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='905']"
            id="BDS905">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='927']"
            id="BDS927">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='928']"
            id="BDS928">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='930']"
            id="BDS930">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='931']"
            id="BDS931">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='932']"
            id="BDS932">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='933']"
            id="BDS933">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='934']"
            id="BDS934">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='935']"
            id="BDS935">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='936']"
            id="BDS936">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='937']"
            id="BDS937">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='938']"
            id="BDS938">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='939']"
            id="BDS939">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='909']"
            id="BDS909">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='913']"
            id="BDS913">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='921']"
            id="BDS921">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='947']"
            id="BDS947">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='943']"
            id="BDS943">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='940']"
            id="BDS940">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='941']"
            id="BDS941">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='950']"
            id="BDS950">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='948']"
            id="BDS948">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='949']"
            id="BDS949">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='954']"
            id="BDS954">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='953']"
            id="BDS953">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='973']"
            id="BDS973">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='984']"
            id="BDS984">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='982']"
            id="BDS982">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='980']"
            id="BDS980">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='998']"
            id="BDS998">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1278']"
            id="BDS1278">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.343' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.343 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='925']"
            id="BDS925">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='923']"
            id="BDS923">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.153' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.153 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:targetSiteCode">Er moet een element 'targetSiteCode' aanwezig zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS924">
         <assert role="error"
                 test="hl7:targetSiteCode/@codeSystem='2.16.840.1.113883.2.4.4.40.13'">De OID van targetSiteCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.13 zijn.</assert>
         <assert role="error" test="hl7:value">Er moet een element 'value' aanwezig zijn.</assert>
         <assert role="error" test="hl7:code">Er moet een element 'code' aanwezig zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>BFMT</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R043']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1382">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1005']"
            id="BDS1005">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1006']"
            id="BDS1006">
         <assert role="error" test="hl7:value/@xsi:type='ED'">Het datatype van value moet ED zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1035']"
            id="BDS1035">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1036']"
            id="BDS1036">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1037']"
            id="BDS1037">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1038']"
            id="BDS1038">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1039']"
            id="BDS1039">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1040']"
            id="BDS1040">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1045']"
            id="BDS1045">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1007']"
            id="BDS1007">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.344' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.344 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1008']"
            id="BDS1008">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.345' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.345 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1009']"
            id="BDS1009">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.346' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.346 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1010']"
            id="BDS1010">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.347' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.347 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1011']"
            id="BDS1011">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.348' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.348 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1012']"
            id="BDS1012">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.349' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.349 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1013']"
            id="BDS1013">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.349' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.349 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1014']"
            id="BDS1014">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.350' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.350 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1015']"
            id="BDS1015">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.351' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.351 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1016']"
            id="BDS1016">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.352' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.352 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1017']"
            id="BDS1017">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.353' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.353 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1018']"
            id="BDS1018">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.353' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.353 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1019']"
            id="BDS1019">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.354' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.354 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1020']"
            id="BDS1020">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.354' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.354 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1021']"
            id="BDS1021">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.355' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.355 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1022']"
            id="BDS1022">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.356' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.356 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1023']"
            id="BDS1023">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.357' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.357 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1024']"
            id="BDS1024">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.357' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.357 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1025']"
            id="BDS1025">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.358' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.358 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1026']"
            id="BDS1026">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.359' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.359 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1027']"
            id="BDS1027">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.360' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.360 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1028']"
            id="BDS1028">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.361' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.361 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1029']"
            id="BDS1029">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.362' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.362 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1030']"
            id="BDS1030">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.363' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.363 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1031']"
            id="BDS1031">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.363' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.363 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1032']"
            id="BDS1032">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.364' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.364 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1033']"
            id="BDS1033">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.365' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.365 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1034']"
            id="BDS1034">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.366' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.366 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1042']"
            id="BDS1042">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.367' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.367 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>SDQ 7-12</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R045']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1103']"
            id="BDS1103">
         <assert role="error" test="hl7:value/@xsi:type='ST'">Het datatype van value moet ST zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1112">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1113">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1114">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1115">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1116">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='']"
            id="BDS1117">
         <assert role="error" test="hl7:value/@xsi:type='PQ'">Het datatype van value moet PQ zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1101']"
            id="BDS1101">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1102']"
            id="BDS1102">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1093']"
            id="BDS1093">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1094']"
            id="BDS1094">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1095']"
            id="BDS1095">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1096']"
            id="BDS1096">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1097']"
            id="BDS1097">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1098']"
            id="BDS1098">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1099']"
            id="BDS1099">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1100']"
            id="BDS1100">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1078']"
            id="BDS1078">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1079']"
            id="BDS1079">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1080']"
            id="BDS1080">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1081']"
            id="BDS1081">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1082']"
            id="BDS1082">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1083']"
            id="BDS1083">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1084']"
            id="BDS1084">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1085']"
            id="BDS1085">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1086']"
            id="BDS1086">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1087']"
            id="BDS1087">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1088']"
            id="BDS1088">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1089']"
            id="BDS1089">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1090']"
            id="BDS1090">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1091']"
            id="BDS1091">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1092']"
            id="BDS1092">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.368' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.368 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1104']"
            id="BDS1104">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.369' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.369 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1105']"
            id="BDS1105">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.370' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.370 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1106']"
            id="BDS1106">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.371' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.371 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1107']"
            id="BDS1107">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.371' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.371 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1108']"
            id="BDS1108">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.371' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.371 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1109']"
            id="BDS1109">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.371' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.371 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1110']"
            id="BDS1110">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.371' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.371 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1111']"
            id="BDS1111">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.371' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.371 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Conclusies en vervolgstappen</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:subjectOf1/hl7:Conclusion/hl7:component/hl7:Indication">
         <assert role="error" test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.373'">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.373 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Zorgplan</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component6/hl7:CarePlan/hl7:reasonOf/hl7:Problem">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='1151'">De waarde van code/@code moet 1151 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component6/hl7:CarePlan/hl7:reasonOf/hl7:Problem/hl7:subjectOf/hl7:Symptoms">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
         <assert role="error" test="hl7:code/@code='1153'">De waarde van code/@code moet 1153 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component6/hl7:CarePlan/hl7:finalGoal/hl7:observationGoal">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component6/hl7:CarePlan/hl7:component/hl7:observationIntent">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component6/hl7:CarePlan/hl7:pertinentInformation/hl7:EvaluationEvent">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Screening logopedie</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R049']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
         <assert role="error"
                 test="count(hl7:component/hl7:observation[hl7:code/@code=1173])&gt;=1">Element 1173, '0. Stoornis' moet minimaal 1 keer voorkomen</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1173']"
            id="BDS1173">
         <assert role="error" test="hl7:value/@xsi:type='BL'">Het datatype van value moet BL zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1182']"
            id="BDS1182">
         <assert role="error" test="hl7:value/@xsi:type='ED'">Het datatype van value moet ED zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1174']"
            id="BDS1174">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.378' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.378 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1175']"
            id="BDS1175">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.379' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.379 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1176']"
            id="BDS1176">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.380' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.380 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1177']"
            id="BDS1177">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.381' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.381 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1178']"
            id="BDS1178">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.382' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.382 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1179']"
            id="BDS1179">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.383' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.383 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1180']"
            id="BDS1180">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.384' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.384 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1181']"
            id="BDS1181">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error"
                 test="hl7:value/@codeSystem='2.16.840.1.113883.2.4.4.40.385' or (hl7:value/@nullFlavor='OTH' and hl7:value/hl7:originalText)">De OID van value/@codeSystem moet 2.16.840.1.113883.2.4.4.40.385 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Zorggegevens</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:Summary/hl7:observationEvent">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:authorization/hl7:VaccinationAuthorizationConsent/hl7:author/hl7:AssignedPerson">
         <assert role="error" test="not(hl7:id) or hl7:id/@root='2.16.528.1.1007.3.1'">De OID van id/@root moet 2.16.528.1.1007.3.1 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Meldingen</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:RegistrationEvent/hl7:subjectOf/hl7:Annotation">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:RegistrationEvent/hl7:perfomer/hl7:AssignedPerson">
         <assert role="error" test="hl7:id/@root='2.16.528.1.1007.3.1'">De OID van id/@root moet 2.16.528.1.1007.3.1 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:EncounterEvent/hl7:performer/hl7:AssignedPerson">
         <assert role="error" test="hl7:id/@root='2.16.528.1.1007.3.1'">De OID van id/@root moet 2.16.528.1.1007.3.1 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:RegistrationEvent/hl7:performer/hl7:AssignedPerson">
         <assert role="error" test="hl7:id/@root='2.16.528.1.1007.3.1'">De OID van id/@root moet 2.16.528.1.1007.3.1 zijn.</assert>
      </rule>
   </pattern>
   <pattern>
      <title>Screening psychosociale problemen</title>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster[hl7:code/@code='R054']">
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.391'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.391 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1345']"
            id="BDS1345">
         <assert role="error" test="hl7:value/@xsi:type='ED'">Het datatype van value moet ED zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1346']"
            id="BDS1346">
         <assert role="error" test="hl7:value/@xsi:type='CV'">Het datatype van value moet CV zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
      <rule context="hl7:CareProvisionRequest/hl7:sequelTo/hl7:careProvisionEvent/hl7:component/*/hl7:pertinentInformation/hl7:rubricCluster/hl7:component/hl7:observation[hl7:code/@code='1341']"
            id="BDS1341">
         <assert role="error" test="hl7:methodCode/@codeSystem='2.16.840.1.113883.2.4.4.40.387'">De OID van methodCode/@codeSystem moet 2.16.840.1.113883.2.4.4.40.387 zijn.</assert>
         <assert role="error" test="hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.40.267'">De OID van code/@codeSystem moet 2.16.840.1.113883.2.4.4.40.267 zijn.</assert>
      </rule>
   </pattern>
</schema>